SET default_tablespace = georitm;

CREATE SEQUENCE georitm.tariff_id_seq;

CREATE TABLE georitm.tariff (
  id INTEGER NOT NULL DEFAULT nextval('georitm.tariff_id_seq'::regclass),
  name VARCHAR(255) NOT NULL,
  comment VARCHAR(1024),
  CONSTRAINT tariff_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.tariff IS 'Тарифы';
COMMENT ON COLUMN georitm.tariff.id IS 'Идентификатор тарифа';
COMMENT ON COLUMN georitm.tariff.name IS 'Наименование тарифа';
COMMENT ON COLUMN georitm.tariff.comment IS 'Примечание';


ALTER SEQUENCE georitm.tariff_id_seq OWNED BY georitm.tariff.id;

CREATE SEQUENCE georitm.tariff_version_id_seq;

CREATE TABLE georitm.tariff_version (
  id INTEGER NOT NULL DEFAULT nextval('georitm.tariff_version_id_seq'::regclass),
  tariff_id INTEGER NOT NULL,
  start_ts TIMESTAMP NOT NULL,
  end_ts TIMESTAMP,
  CONSTRAINT tariff_version_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.tariff_version IS 'Версия тарифа';
COMMENT ON COLUMN georitm.tariff_version.id IS 'Идентификатор версии тарифа';
COMMENT ON COLUMN georitm.tariff_version.tariff_id IS 'Ссылка на таблицу tariff';
COMMENT ON COLUMN georitm.tariff_version.start_ts IS 'Дата начала действия версии тарифа';
COMMENT ON COLUMN georitm.tariff_version.end_ts IS 'Дата окончания действия версии тарифа';


ALTER SEQUENCE georitm.tariff_version_id_seq OWNED BY georitm.tariff_version.id;

CREATE UNIQUE INDEX tariff_start_ts_idx
  ON georitm.tariff_version
  ( tariff_id, start_ts );

CREATE TABLE georitm.tariff_scale (
  tariff_version_id INTEGER NOT NULL,
  num_objects INTEGER NOT NULL,
  price NUMERIC(9,2) NOT NULL,
  CONSTRAINT tariff_scale_pk PRIMARY KEY (tariff_version_id, num_objects)
);
COMMENT ON TABLE georitm.tariff_scale IS 'Тарифная сетка';
COMMENT ON COLUMN georitm.tariff_scale.tariff_version_id IS 'Ссылка на Версию тарифа';
COMMENT ON COLUMN georitm.tariff_scale.num_objects IS 'Количество объектов';
COMMENT ON COLUMN georitm.tariff_scale.price IS 'Цена за колиество объектов';


CREATE TABLE georitm.alert_channels (
  name VARCHAR(500) NOT NULL,
  CONSTRAINT alert_channels_pk PRIMARY KEY (name)
);
COMMENT ON TABLE georitm.alert_channels IS 'Справочник каналов подключений';


CREATE TABLE georitm.instance_id (
  id CHAR(36) NOT NULL,
  mac VARCHAR(255) NOT NULL,
  CONSTRAINT instance_id_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.instance_id IS 'Идентификатор сервиса';


CREATE SEQUENCE georitm.online_recalc_tasks_id_seq;

CREATE TABLE georitm.online_recalc_tasks (
  id INTEGER NOT NULL DEFAULT nextval('georitm.online_recalc_tasks_id_seq'::regclass),
  object_id INTEGER NOT NULL,
  date_from TIMESTAMP NOT NULL,
  CONSTRAINT online_recalc_tasks_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.online_recalc_tasks IS 'Задачи на пересчет';
COMMENT ON COLUMN georitm.online_recalc_tasks.id IS 'Идентификатор';
COMMENT ON COLUMN georitm.online_recalc_tasks.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm.online_recalc_tasks.date_from IS 'Дата начала';


ALTER SEQUENCE georitm.online_recalc_tasks_id_seq OWNED BY georitm.online_recalc_tasks.id;

CREATE SEQUENCE georitm.erase_tasks_id_seq;

CREATE TABLE georitm.erase_tasks (
  id INTEGER NOT NULL DEFAULT nextval('georitm.erase_tasks_id_seq'::regclass),
  object_id INTEGER NOT NULL,
  CONSTRAINT erase_tasks_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.erase_tasks IS 'Задачи на удаление данных';
COMMENT ON COLUMN georitm.erase_tasks.id IS 'Идентификатор';
COMMENT ON COLUMN georitm.erase_tasks.object_id IS 'Идентификатор объекта';


ALTER SEQUENCE georitm.erase_tasks_id_seq OWNED BY georitm.erase_tasks.id;

CREATE TABLE georitm.terminals (
  imei BIGINT NOT NULL,
  inv_num VARCHAR(25) NOT NULL,
  model VARCHAR(50),
  CONSTRAINT terminals_pk PRIMARY KEY (imei)
);
COMMENT ON TABLE georitm.terminals IS 'Справочник терминалов';
COMMENT ON COLUMN georitm.terminals.imei IS 'IMEI оборудования';
COMMENT ON COLUMN georitm.terminals.inv_num IS 'Уникальный инвентаризационный номер';
COMMENT ON COLUMN georitm.terminals.model IS 'Модель оборудования';


CREATE UNIQUE INDEX inv_num_idx
  ON georitm.terminals
  ( inv_num );

CREATE TABLE georitm.alert_action_type (
  id SMALLINT NOT NULL,
  name VARCHAR(512) NOT NULL,
  CONSTRAINT alert_action_type_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.alert_action_type IS 'Типы действий на тревоги';
COMMENT ON COLUMN georitm.alert_action_type.id IS 'Идентификатор (Номер действия)';
COMMENT ON COLUMN georitm.alert_action_type.name IS 'Наименование действия';


CREATE SEQUENCE georitm.alert_action_template_id_seq;

CREATE TABLE georitm.alert_action_template (
  id INTEGER NOT NULL DEFAULT nextval('georitm.alert_action_template_id_seq'::regclass),
  act_type_id SMALLINT NOT NULL,
  num SMALLINT NOT NULL,
  name VARCHAR(512) NOT NULL,
  CONSTRAINT alert_action_template_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.alert_action_template IS 'Шаблоны действий';
COMMENT ON COLUMN georitm.alert_action_template.id IS 'Идентификатор';
COMMENT ON COLUMN georitm.alert_action_template.act_type_id IS 'Номер действия';
COMMENT ON COLUMN georitm.alert_action_template.num IS 'Порядковый номер в отображении';
COMMENT ON COLUMN georitm.alert_action_template.name IS 'Наименование действия';


ALTER SEQUENCE georitm.alert_action_template_id_seq OWNED BY georitm.alert_action_template.id;

CREATE TABLE georitm.object_state_lbs (
  object_id INTEGER NOT NULL,
  mcc INTEGER,
  mnc INTEGER,
  cell_id INTEGER,
  lac INTEGER,
  rxl INTEGER,
  lbs_date TIMESTAMP NOT NULL,
  CONSTRAINT object_state_lbs_pk PRIMARY KEY (object_id)
);
COMMENT ON TABLE georitm.object_state_lbs IS 'Данные о положении от сети GSM';
COMMENT ON COLUMN georitm.object_state_lbs.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm.object_state_lbs.mcc IS 'MCC';
COMMENT ON COLUMN georitm.object_state_lbs.mnc IS 'MNC';
COMMENT ON COLUMN georitm.object_state_lbs.cell_id IS 'Идентификатор соты';
COMMENT ON COLUMN georitm.object_state_lbs.lac IS 'Код локальной зоны';
COMMENT ON COLUMN georitm.object_state_lbs.rxl IS 'Уровень сигнала';
COMMENT ON COLUMN georitm.object_state_lbs.lbs_date IS 'Дата фиксации';


CREATE TABLE georitm.client_statiscics (
  client_id INTEGER NOT NULL,
  day_ts TIMESTAMP NOT NULL,
  statistic_key VARCHAR(255) NOT NULL,
  statistic_value VARCHAR(255),
  CONSTRAINT client_statiscics_pk PRIMARY KEY (client_id, day_ts, statistic_key)
);
COMMENT ON TABLE georitm.client_statiscics IS 'Статистика по клиенту';
COMMENT ON COLUMN georitm.client_statiscics.client_id IS 'Идентификатор клиента';
COMMENT ON COLUMN georitm.client_statiscics.day_ts IS 'Штамп времени начала суток';
COMMENT ON COLUMN georitm.client_statiscics.statistic_key IS 'Ключ';
COMMENT ON COLUMN georitm.client_statiscics.statistic_value IS 'Значение';


CREATE TABLE georitm.object_state_prm (
  object_id INTEGER NOT NULL,
  alt INTEGER,
  voltage INTEGER,
  voltage_type INTEGER,
  temperature SMALLINT,
  CONSTRAINT object_state_prm_pk PRIMARY KEY (object_id)
);
COMMENT ON COLUMN georitm.object_state_prm.object_id IS 'Идентификатор объект';
COMMENT ON COLUMN georitm.object_state_prm.alt IS 'Высота';
COMMENT ON COLUMN georitm.object_state_prm.voltage IS 'Бортовое напряжение';
COMMENT ON COLUMN georitm.object_state_prm.voltage_type IS 'Тип напряжения (внешнее основное / резервное АКБ)';
COMMENT ON COLUMN georitm.object_state_prm.temperature IS 'Температура';


CREATE SEQUENCE georitm.alert_comments_id_seq;

CREATE TABLE georitm.alert_comments (
  id INTEGER NOT NULL DEFAULT nextval('georitm.alert_comments_id_seq'::regclass),
  client_id INTEGER NOT NULL,
  msg VARCHAR(4096) NOT NULL,
  num INTEGER NOT NULL,
  CONSTRAINT alert_comments_pk PRIMARY KEY (id)
);
COMMENT ON COLUMN georitm.alert_comments.id IS 'Идентификатор';
COMMENT ON COLUMN georitm.alert_comments.client_id IS 'Идентификатор клиента';
COMMENT ON COLUMN georitm.alert_comments.msg IS 'коментарий';
COMMENT ON COLUMN georitm.alert_comments.num IS 'номер коментария';


ALTER SEQUENCE georitm.alert_comments_id_seq OWNED BY georitm.alert_comments.id;

CREATE SEQUENCE georitm.alert_comments_template_id_seq;

CREATE TABLE georitm.alert_comments_template (
  id INTEGER NOT NULL DEFAULT nextval('georitm.alert_comments_template_id_seq'::regclass),
  msg VARCHAR(4096) NOT NULL,
  num INTEGER NOT NULL,
  CONSTRAINT alert_comments_template_pk PRIMARY KEY (id)
);
COMMENT ON COLUMN georitm.alert_comments_template.id IS 'Идентификатор';
COMMENT ON COLUMN georitm.alert_comments_template.msg IS 'Коментарий';
COMMENT ON COLUMN georitm.alert_comments_template.num IS 'Номер коментария';


ALTER SEQUENCE georitm.alert_comments_template_id_seq OWNED BY georitm.alert_comments_template.id;

CREATE TABLE georitm.alert_template_group (
  id INTEGER NOT NULL,
  name VARCHAR(255) NOT NULL,
  CONSTRAINT alert_template_group_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.alert_template_group IS 'Группы шаблонов тревожных сообщений';
COMMENT ON COLUMN georitm.alert_template_group.id IS 'Идентификатор группы шаблонов тревожных сообщений';
COMMENT ON COLUMN georitm.alert_template_group.name IS 'Имя группы шаблолнов тревожных сообщений';


CREATE SEQUENCE georitm.alert_messages_id_seq;

CREATE TABLE georitm.alert_messages (
  id INTEGER NOT NULL DEFAULT nextval('georitm.alert_messages_id_seq'::regclass),
  message_text VARCHAR(2048) NOT NULL,
  code INTEGER NOT NULL,
  fg_color VARCHAR(8),
  template_id INTEGER NOT NULL,
  bg_color VARCHAR(8),
  is_visible BOOLEAN DEFAULT true NOT NULL,
  template_version INTEGER DEFAULT 1 NOT NULL,
  CONSTRAINT alert_messages_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.alert_messages IS 'Типовые сообщения';
COMMENT ON COLUMN georitm.alert_messages.id IS 'Идентификатор типового сообщения';
COMMENT ON COLUMN georitm.alert_messages.message_text IS 'Сообщение';
COMMENT ON COLUMN georitm.alert_messages.code IS 'Коды Ademco Contact ID и пользовательские коды';
COMMENT ON COLUMN georitm.alert_messages.fg_color IS 'Цвет текста';
COMMENT ON COLUMN georitm.alert_messages.template_id IS 'Идентификатор шаблона.';
COMMENT ON COLUMN georitm.alert_messages.bg_color IS 'Цвет фона';
COMMENT ON COLUMN georitm.alert_messages.is_visible IS 'Показывать ли сообщения в ленте событий';


ALTER SEQUENCE georitm.alert_messages_id_seq OWNED BY georitm.alert_messages.id;

CREATE INDEX alert_messages_idx
  ON georitm.alert_messages
  ( code, template_id );

CREATE TABLE georitm.object_state (
  object_id INTEGER NOT NULL,
  lat INTEGER,
  lon INTEGER,
  spd INTEGER,
  course INTEGER,
  control_in_1 INTEGER,
  control_in_2 INTEGER,
  control_mode INTEGER NOT NULL,
  last_gsm_time TIMESTAMP,
  last_gps_time TIMESTAMP,
  local_rid INTEGER,
  remote_rid INTEGER,
  CONSTRAINT object_state_pk PRIMARY KEY (object_id)
);
COMMENT ON TABLE georitm.object_state IS 'Состояние объекта';
COMMENT ON COLUMN georitm.object_state.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm.object_state.lat IS 'Широта';
COMMENT ON COLUMN georitm.object_state.lon IS 'Долгота';
COMMENT ON COLUMN georitm.object_state.spd IS 'Скорость';
COMMENT ON COLUMN georitm.object_state.course IS 'Курс';
COMMENT ON COLUMN georitm.object_state.control_in_1 IS 'Состояние контрольного входа 1';
COMMENT ON COLUMN georitm.object_state.control_in_2 IS 'Состояние контрольного входа 2';
COMMENT ON COLUMN georitm.object_state.control_mode IS 'Режим управления';
COMMENT ON COLUMN georitm.object_state.last_gsm_time IS 'Штамп времени последней связи объекта по GSM';
COMMENT ON COLUMN georitm.object_state.last_gps_time IS 'Штамп времени последней связи объекта по GPS';
COMMENT ON COLUMN georitm.object_state.local_rid IS 'Переданный идентификатор записи в приборе';
COMMENT ON COLUMN georitm.object_state.remote_rid IS 'Текущий идентификатор записи в приборе';


CREATE SEQUENCE georitm.user_log_id_seq;

CREATE TABLE georitm.user_log (
  id BIGINT NOT NULL DEFAULT nextval('georitm.user_log_id_seq'::regclass),
  log_ts TIMESTAMP NOT NULL,
  user_id INTEGER,
  user_ext_id INTEGER,
  username VARCHAR(100),
  action VARCHAR(127),
  add_info TEXT,
  is_successed BOOLEAN,
  CONSTRAINT user_log_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.user_log IS 'Журнал действий пользователя';
COMMENT ON COLUMN georitm.user_log.id IS 'Идентификатор журнала';
COMMENT ON COLUMN georitm.user_log.log_ts IS 'Штамп вренмени записи в журнал';
COMMENT ON COLUMN georitm.user_log.user_id IS 'Идентификатор пользователя';
COMMENT ON COLUMN georitm.user_log.user_ext_id IS 'о импорта, потом может быть удален.';
COMMENT ON COLUMN georitm.user_log.username IS 'Имя пользователя';
COMMENT ON COLUMN georitm.user_log.action IS 'Действие';
COMMENT ON COLUMN georitm.user_log.add_info IS 'Дополнительная информация';
COMMENT ON COLUMN georitm.user_log.is_successed IS 'Флаг успешного выполнения';


ALTER SEQUENCE georitm.user_log_id_seq OWNED BY georitm.user_log.id;

CREATE INDEX user_log_ts_idx
  ON georitm.user_log
  ( log_ts );

CREATE SEQUENCE georitm.user_log_details_id_seq;

CREATE TABLE georitm.user_log_details (
  id BIGINT NOT NULL DEFAULT nextval('georitm.user_log_details_id_seq'::regclass),
  user_log_id BIGINT NOT NULL,
  affected_id BIGINT NOT NULL,
  affected_ext_id BIGINT,
  affected_name VARCHAR(255),
  affected_class VARCHAR(255) NOT NULL,
  CONSTRAINT user_log_details_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.user_log_details IS 'Дополнительная информация о действиях пользователей';
COMMENT ON COLUMN georitm.user_log_details.id IS 'Идентификатор действия';
COMMENT ON COLUMN georitm.user_log_details.user_log_id IS 'Идентификатор журнала действий пользователя';
COMMENT ON COLUMN georitm.user_log_details.affected_id IS 'Идентификатор вызова';
COMMENT ON COLUMN georitm.user_log_details.affected_ext_id IS 'Внешний идентификатор вызова';
COMMENT ON COLUMN georitm.user_log_details.affected_name IS 'Имя вызова';
COMMENT ON COLUMN georitm.user_log_details.affected_class IS 'Класс вызова';


ALTER SEQUENCE georitm.user_log_details_id_seq OWNED BY georitm.user_log_details.id;

CREATE SEQUENCE georitm.clients_id_seq;

CREATE TABLE georitm.clients (
  id INTEGER NOT NULL DEFAULT nextval('georitm.clients_id_seq'::regclass),
  name VARCHAR(2056) NOT NULL,
  reg_date TIMESTAMP,
  confirm_date TIMESTAMP,
  exp_date TIMESTAMP,
  CONSTRAINT clients_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.clients IS 'Клиент';
COMMENT ON COLUMN georitm.clients.id IS 'Идентификатор клиента';
COMMENT ON COLUMN georitm.clients.name IS 'Имя клиента';
COMMENT ON COLUMN georitm.clients.reg_date IS 'Дата регистрации';
COMMENT ON COLUMN georitm.clients.confirm_date IS 'Дата подтверждения регистрации';
COMMENT ON COLUMN georitm.clients.exp_date IS 'Дата окончания обслуживания';


ALTER SEQUENCE georitm.clients_id_seq OWNED BY georitm.clients.id;

CREATE TABLE georitm.accounts (
  uuid VARCHAR(36) NOT NULL,
  name VARCHAR(255),
  client_id INTEGER NOT NULL,
  balance_ts TIMESTAMP NOT NULL,
  balance NUMERIC(12,2) NOT NULL,
  CONSTRAINT accounts_pk PRIMARY KEY (uuid)
);
COMMENT ON TABLE georitm.accounts IS 'Лицевой счет клиента';
COMMENT ON COLUMN georitm.accounts.uuid IS 'Идентификатор счета';
COMMENT ON COLUMN georitm.accounts.name IS 'Наименование счёта';
COMMENT ON COLUMN georitm.accounts.client_id IS 'Идентификатор клиента';
COMMENT ON COLUMN georitm.accounts.balance_ts IS 'Таймстамп расчета баланса';
COMMENT ON COLUMN georitm.accounts.balance IS 'Баланс счета';


CREATE UNIQUE INDEX account_idx
  ON georitm.accounts
  ( client_id );

CREATE SEQUENCE georitm.invoice_id_seq;

CREATE TABLE georitm.invoice (
  id INTEGER NOT NULL DEFAULT nextval('georitm.invoice_id_seq'::regclass),
  account_uuid VARCHAR(36) NOT NULL,
  num VARCHAR(64) NOT NULL,
  invoice_date DATE NOT NULL,
  create_ts TIMESTAMP NOT NULL,
  amount NUMERIC(12,2) NOT NULL,
  status SMALLINT DEFAULT 0 NOT NULL,
  CONSTRAINT invoice_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.invoice IS 'Счёт на оплату услуг';
COMMENT ON COLUMN georitm.invoice.id IS 'Идентификатор счёта';
COMMENT ON COLUMN georitm.invoice.account_uuid IS 'Идентификатор счета';
COMMENT ON COLUMN georitm.invoice.num IS 'Номер счета';
COMMENT ON COLUMN georitm.invoice.invoice_date IS 'Счёт от';
COMMENT ON COLUMN georitm.invoice.create_ts IS 'Таймстамп создания';
COMMENT ON COLUMN georitm.invoice.amount IS 'Сумма счёта';
COMMENT ON COLUMN georitm.invoice.status IS 'Состояние';


ALTER SEQUENCE georitm.invoice_id_seq OWNED BY georitm.invoice.id;

CREATE TABLE georitm.income (
  account_uuid VARCHAR(36) NOT NULL,
  ts TIMESTAMP NOT NULL,
  type SMALLINT DEFAULT 0 NOT NULL,
  comment VARCHAR(1024) NOT NULL,
  amount NUMERIC(12,2) NOT NULL,
  doc_id INTEGER,
  CONSTRAINT income_pk PRIMARY KEY (account_uuid, ts)
);
COMMENT ON TABLE georitm.income IS 'Поступление средств';
COMMENT ON COLUMN georitm.income.account_uuid IS 'Идентификатор счета';
COMMENT ON COLUMN georitm.income.ts IS 'Время';
COMMENT ON COLUMN georitm.income.type IS 'Тип пополнения';
COMMENT ON COLUMN georitm.income.comment IS 'Назначение плвтежа';
COMMENT ON COLUMN georitm.income.amount IS 'Сумма зачисления';
COMMENT ON COLUMN georitm.income.doc_id IS 'Ссылка на "Документ"';


CREATE TABLE georitm.expense (
  account_uuid VARCHAR(36) NOT NULL,
  ts TIMESTAMP NOT NULL,
  comment VARCHAR(1024) NOT NULL,
  amount NUMERIC(12,2) NOT NULL,
  num_objects INTEGER NOT NULL,
  doc_id INTEGER,
  CONSTRAINT expense_pk PRIMARY KEY (account_uuid, ts)
);
COMMENT ON TABLE georitm.expense IS 'Расход средств';
COMMENT ON COLUMN georitm.expense.account_uuid IS 'Идентификатор счета';
COMMENT ON COLUMN georitm.expense.ts IS 'Время';
COMMENT ON COLUMN georitm.expense.comment IS 'Назначение плвтежа';
COMMENT ON COLUMN georitm.expense.amount IS 'Сумма списания';
COMMENT ON COLUMN georitm.expense.num_objects IS 'Общее количество объектов на момент списания. Учитываются как бесплатные, так и платные';
COMMENT ON COLUMN georitm.expense.doc_id IS 'Ссылка на "Документ"';


CREATE TABLE georitm.client_tariff (
  tariff_id INTEGER NOT NULL,
  client_id INTEGER NOT NULL,
  start_ts TIMESTAMP NOT NULL,
  end_ts TIMESTAMP,
  CONSTRAINT client_tariff_pk PRIMARY KEY (tariff_id, client_id, start_ts)
);
COMMENT ON TABLE georitm.client_tariff IS 'Тарифы клиентов';
COMMENT ON COLUMN georitm.client_tariff.tariff_id IS 'Ссылка на Тариф';
COMMENT ON COLUMN georitm.client_tariff.client_id IS 'Ссылка на Клиента';
COMMENT ON COLUMN georitm.client_tariff.start_ts IS 'Дата начала действия тарифа для клиента';
COMMENT ON COLUMN georitm.client_tariff.end_ts IS 'Дата окончания действия тарифа для клиента';


CREATE UNIQUE INDEX client_tariff_start_ts_idx
  ON georitm.client_tariff
  ( client_id, start_ts );

CREATE SEQUENCE georitm.alert_action_id_seq;

CREATE TABLE georitm.alert_action (
  id INTEGER NOT NULL DEFAULT nextval('georitm.alert_action_id_seq'::regclass),
  act_type_id SMALLINT NOT NULL,
  client_id INTEGER NOT NULL,
  num SMALLINT NOT NULL,
  name VARCHAR(512) NOT NULL,
  CONSTRAINT alert_action_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.alert_action IS 'Действия в привязке к клиентам';
COMMENT ON COLUMN georitm.alert_action.id IS 'Идентификатор';
COMMENT ON COLUMN georitm.alert_action.act_type_id IS 'Номер действия';
COMMENT ON COLUMN georitm.alert_action.client_id IS 'Идентификатор клиента';
COMMENT ON COLUMN georitm.alert_action.num IS 'Порядковый номер в отображении';
COMMENT ON COLUMN georitm.alert_action.name IS 'Наименование действия';


ALTER SEQUENCE georitm.alert_action_id_seq OWNED BY georitm.alert_action.id;

CREATE INDEX alert_action_client_id_idx
  ON georitm.alert_action
  ( client_id );

CREATE TABLE georitm.client_properties (
  client_id INTEGER NOT NULL,
  property_key VARCHAR(255) NOT NULL,
  property_value VARCHAR(2048) NOT NULL,
  CONSTRAINT client_properties_pk PRIMARY KEY (client_id, property_key)
);
COMMENT ON TABLE georitm.client_properties IS 'Свойства клиента';
COMMENT ON COLUMN georitm.client_properties.client_id IS 'Идентификатор клиента';
COMMENT ON COLUMN georitm.client_properties.property_key IS 'Ключ свойства';
COMMENT ON COLUMN georitm.client_properties.property_value IS 'Значение свойства';


CREATE SEQUENCE georitm.alert_template_id_seq;

CREATE TABLE georitm.alert_template (
  id INTEGER NOT NULL DEFAULT nextval('georitm.alert_template_id_seq'::regclass),
  client_id INTEGER,
  group_id INTEGER NOT NULL,
  code INTEGER NOT NULL,
  message VARCHAR(255) NOT NULL,
  fg_color VARCHAR(8),
  bg_color VARCHAR(8),
  is_visible BOOLEAN NOT NULL,
  is_alarm BOOLEAN NOT NULL,
  is_relayed BOOLEAN DEFAULT false NOT NULL,
  version INTEGER DEFAULT 1 NOT NULL,
  CONSTRAINT alert_template_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.alert_template IS 'Шаблон тревожного сообщения';
COMMENT ON COLUMN georitm.alert_template.id IS 'Идентификатор шаблона тревожного сообщения';
COMMENT ON COLUMN georitm.alert_template.client_id IS 'Идентификатор клиента';
COMMENT ON COLUMN georitm.alert_template.group_id IS 'Идентификатор группы сообщений';
COMMENT ON COLUMN georitm.alert_template.code IS 'Код сообщения';
COMMENT ON COLUMN georitm.alert_template.message IS 'Символьное сообщение';
COMMENT ON COLUMN georitm.alert_template.fg_color IS 'Цвет текста';
COMMENT ON COLUMN georitm.alert_template.bg_color IS 'Цвет фона';
COMMENT ON COLUMN georitm.alert_template.is_visible IS 'Показывать ли событие на ленте';
COMMENT ON COLUMN georitm.alert_template.is_alarm IS 'Является ли тревогой';
COMMENT ON COLUMN georitm.alert_template.is_relayed IS 'Ретранслируется ли во внешние системы (зарезервировано)';


ALTER SEQUENCE georitm.alert_template_id_seq OWNED BY georitm.alert_template.id;

CREATE INDEX alert_template_idx
  ON georitm.alert_template
  ( code );

CREATE SEQUENCE georitm.poi_types_id_seq;

CREATE TABLE georitm.poi_types (
  id INTEGER NOT NULL DEFAULT nextval('georitm.poi_types_id_seq'::regclass),
  name VARCHAR(255) NOT NULL,
  ext_id INTEGER,
  client_id INTEGER NOT NULL,
  code VARCHAR(20) NOT NULL,
  CONSTRAINT poi_types_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.poi_types IS 'Справочник типов меток';
COMMENT ON COLUMN georitm.poi_types.id IS 'Идентификатор типа метки';
COMMENT ON COLUMN georitm.poi_types.name IS 'Имя типа метки';
COMMENT ON COLUMN georitm.poi_types.ext_id IS 'о импорта, потом может быть удален.';
COMMENT ON COLUMN georitm.poi_types.client_id IS 'Идентификатор клиента';
COMMENT ON COLUMN georitm.poi_types.code IS 'Мнемонический код типа';


ALTER SEQUENCE georitm.poi_types_id_seq OWNED BY georitm.poi_types.id;

CREATE TABLE georitm.poi_type_properties (
  poi_type_id INTEGER NOT NULL,
  property_key VARCHAR(255) NOT NULL,
  CONSTRAINT poi_type_properties_pk PRIMARY KEY (poi_type_id, property_key)
);
COMMENT ON TABLE georitm.poi_type_properties IS 'Шаблон набора свойств для метки данного типа';
COMMENT ON COLUMN georitm.poi_type_properties.poi_type_id IS 'Идентификатор типа метки';
COMMENT ON COLUMN georitm.poi_type_properties.property_key IS 'Значение ключа свойства';


CREATE SEQUENCE georitm.poi_groups_id_seq;

CREATE TABLE georitm.poi_groups (
  id INTEGER NOT NULL DEFAULT nextval('georitm.poi_groups_id_seq'::regclass),
  name VARCHAR(1024) NOT NULL,
  client_id INTEGER NOT NULL,
  parent_id INTEGER,
  CONSTRAINT poi_groups_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.poi_groups IS 'Группы меток';
COMMENT ON COLUMN georitm.poi_groups.id IS 'Идентификатор группы меток';
COMMENT ON COLUMN georitm.poi_groups.name IS 'Имя группы меток';
COMMENT ON COLUMN georitm.poi_groups.client_id IS 'Идентификатор клиента';
COMMENT ON COLUMN georitm.poi_groups.parent_id IS 'Идентификатор родительской группы';


ALTER SEQUENCE georitm.poi_groups_id_seq OWNED BY georitm.poi_groups.id;

CREATE SEQUENCE georitm.schedule_template_id_seq;

CREATE TABLE georitm.schedule_template (
  id INTEGER NOT NULL DEFAULT nextval('georitm.schedule_template_id_seq'::regclass),
  name VARCHAR(1024) NOT NULL,
  code VARCHAR(256) NOT NULL,
  client_id INTEGER NOT NULL,
  is_shift BOOLEAN NOT NULL,
  template VARCHAR(255) NOT NULL,
  CONSTRAINT schedule_template_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.schedule_template IS 'Шаблон расписания';
COMMENT ON COLUMN georitm.schedule_template.id IS 'Идентификатор шаблона расписания';
COMMENT ON COLUMN georitm.schedule_template.name IS 'Название шаблона';
COMMENT ON COLUMN georitm.schedule_template.code IS 'Мнемонический код шаблона';
COMMENT ON COLUMN georitm.schedule_template.client_id IS 'Идентификатор клиента';
COMMENT ON COLUMN georitm.schedule_template.is_shift IS 'Сменный';
COMMENT ON COLUMN georitm.schedule_template.template IS 'Шфблон';


ALTER SEQUENCE georitm.schedule_template_id_seq OWNED BY georitm.schedule_template.id;

CREATE SEQUENCE georitm.positions_id_seq;

CREATE TABLE georitm.positions (
  id INTEGER NOT NULL DEFAULT nextval('georitm.positions_id_seq'::regclass),
  client_id INTEGER NOT NULL,
  name VARCHAR(512) NOT NULL,
  code VARCHAR(20) NOT NULL,
  CONSTRAINT positions_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.positions IS 'Справочник должностей';
COMMENT ON COLUMN georitm.positions.id IS 'Идентификатор должности';
COMMENT ON COLUMN georitm.positions.client_id IS 'Идентификатор клиента';
COMMENT ON COLUMN georitm.positions.name IS 'Наименование должности';
COMMENT ON COLUMN georitm.positions.code IS 'Код должности';


ALTER SEQUENCE georitm.positions_id_seq OWNED BY georitm.positions.id;

CREATE SEQUENCE georitm.addr_source_id_seq;

CREATE TABLE georitm.addr_source (
  id INTEGER NOT NULL DEFAULT nextval('georitm.addr_source_id_seq'::regclass),
  name VARCHAR(255),
  code VARCHAR(10) NOT NULL,
  CONSTRAINT addr_source_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.addr_source IS 'Источники адресов';
COMMENT ON COLUMN georitm.addr_source.id IS 'Идентификатор источника';
COMMENT ON COLUMN georitm.addr_source.name IS 'Название';
COMMENT ON COLUMN georitm.addr_source.code IS 'Мнемонический код';


ALTER SEQUENCE georitm.addr_source_id_seq OWNED BY georitm.addr_source.id;

CREATE SEQUENCE georitm.geo_address_id_seq;

CREATE TABLE georitm.geo_address (
  id INTEGER NOT NULL DEFAULT nextval('georitm.geo_address_id_seq'::regclass),
  lat INTEGER NOT NULL,
  lon INTEGER NOT NULL,
  CONSTRAINT geo_address_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.geo_address IS 'Адрес географической точки';
COMMENT ON COLUMN georitm.geo_address.id IS 'Идентификатор географической точки';
COMMENT ON COLUMN georitm.geo_address.lat IS 'Широта * 1000000';
COMMENT ON COLUMN georitm.geo_address.lon IS 'Долгота * 1000000';


ALTER SEQUENCE georitm.geo_address_id_seq OWNED BY georitm.geo_address.id;

CREATE INDEX geo_address_lat_idx
  ON georitm.geo_address
  ( lat );

CREATE INDEX geo_address_lon_idx
  ON georitm.geo_address
  ( lon );

CREATE SEQUENCE georitm.guards_id_seq;

CREATE TABLE georitm.guards (
  id INTEGER NOT NULL DEFAULT nextval('georitm.guards_id_seq'::regclass),
  name VARCHAR(255) NOT NULL,
  responsive_person_name VARCHAR(255) NOT NULL,
  responsive_person_phone VARCHAR(50) NOT NULL,
  login VARCHAR(50) NOT NULL,
  password VARCHAR(50) NOT NULL,
  lat INTEGER,
  lon INTEGER,
  spd INTEGER,
  course INTEGER,
  comment VARCHAR(4096) NOT NULL,
  geo_id INTEGER,
  coordinates_time TIMESTAMP,
  CONSTRAINT guards_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.guards IS 'ГБР';
COMMENT ON COLUMN georitm.guards.id IS 'Идентификатор ГБР';
COMMENT ON COLUMN georitm.guards.name IS 'Имя ГБР';
COMMENT ON COLUMN georitm.guards.responsive_person_name IS 'Имя ответственного';
COMMENT ON COLUMN georitm.guards.responsive_person_phone IS 'Телефон ответственного';
COMMENT ON COLUMN georitm.guards.login IS 'Логин';
COMMENT ON COLUMN georitm.guards.password IS 'Пароль';
COMMENT ON COLUMN georitm.guards.lat IS 'Широта';
COMMENT ON COLUMN georitm.guards.lon IS 'Долгота';
COMMENT ON COLUMN georitm.guards.spd IS 'Скорость';
COMMENT ON COLUMN georitm.guards.course IS 'Курс';
COMMENT ON COLUMN georitm.guards.geo_id IS 'Метка адреса';
COMMENT ON COLUMN georitm.guards.coordinates_time IS 'Штамп времени установки координат';


ALTER SEQUENCE georitm.guards_id_seq OWNED BY georitm.guards.id;

CREATE UNIQUE INDEX login_idx
  ON georitm.guards
  ( login );

CREATE SEQUENCE georitm.poi_id_seq;

CREATE TABLE georitm.poi (
  id INTEGER NOT NULL DEFAULT nextval('georitm.poi_id_seq'::regclass),
  name VARCHAR(1024) NOT NULL,
  poi_group_id INTEGER NOT NULL,
  lat INTEGER NOT NULL,
  poi_type_id INTEGER NOT NULL,
  lon INTEGER NOT NULL,
  create_date TIMESTAMP NOT NULL,
  geo_id INTEGER NOT NULL,
  CONSTRAINT poi_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.poi IS 'Метки';
COMMENT ON COLUMN georitm.poi.id IS 'Идентификатор метки';
COMMENT ON COLUMN georitm.poi.name IS 'Имя метки';
COMMENT ON COLUMN georitm.poi.poi_group_id IS 'Идентификатор группы меток';
COMMENT ON COLUMN georitm.poi.lat IS 'Широта';
COMMENT ON COLUMN georitm.poi.poi_type_id IS 'Идентификатор типа метки';
COMMENT ON COLUMN georitm.poi.lon IS 'Долгота';
COMMENT ON COLUMN georitm.poi.create_date IS 'Дата создания';
COMMENT ON COLUMN georitm.poi.geo_id IS 'Идентификатор географической точки';


ALTER SEQUENCE georitm.poi_id_seq OWNED BY georitm.poi.id;

CREATE TABLE georitm.poi_properties (
  poi_id INTEGER NOT NULL,
  property_key VARCHAR(255) NOT NULL,
  value VARCHAR(2048) NOT NULL,
  CONSTRAINT poi_properties_pk PRIMARY KEY (poi_id, property_key)
);
COMMENT ON TABLE georitm.poi_properties IS 'Свойства меток';
COMMENT ON COLUMN georitm.poi_properties.poi_id IS 'Идентификатор метки';
COMMENT ON COLUMN georitm.poi_properties.property_key IS 'Ключ свойства';
COMMENT ON COLUMN georitm.poi_properties.value IS 'Значение';


CREATE TABLE georitm.geo_addr_source (
  address_id INTEGER NOT NULL,
  source_id INTEGER NOT NULL,
  language VARCHAR(8) NOT NULL,
  addr VARCHAR(1024) NOT NULL,
  CONSTRAINT geo_addr_source_pk PRIMARY KEY (address_id, source_id, language)
);
COMMENT ON TABLE georitm.geo_addr_source IS 'Таблица связи и название места адреса';
COMMENT ON COLUMN georitm.geo_addr_source.address_id IS 'Идентификатор географической точки';
COMMENT ON COLUMN georitm.geo_addr_source.source_id IS 'Идентификатор источника';
COMMENT ON COLUMN georitm.geo_addr_source.language IS 'язк-регион';
COMMENT ON COLUMN georitm.geo_addr_source.addr IS 'Символьное название места адреса';


CREATE SEQUENCE georitm.auth_roles_id_seq;

CREATE TABLE georitm.auth_roles (
  id INTEGER NOT NULL DEFAULT nextval('georitm.auth_roles_id_seq'::regclass),
  client_id INTEGER NOT NULL,
  role_code VARCHAR(20) NOT NULL,
  role_name VARCHAR(255) NOT NULL,
  CONSTRAINT auth_roles_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.auth_roles IS 'Роли авторизации';
COMMENT ON COLUMN georitm.auth_roles.id IS 'Идентификатор роли';
COMMENT ON COLUMN georitm.auth_roles.client_id IS 'Идентификатор клиента';
COMMENT ON COLUMN georitm.auth_roles.role_code IS 'Код роли';
COMMENT ON COLUMN georitm.auth_roles.role_name IS 'Имя роли';


ALTER SEQUENCE georitm.auth_roles_id_seq OWNED BY georitm.auth_roles.id;

CREATE SEQUENCE georitm.inventory_id_seq;

CREATE TABLE georitm.inventory (
  id INTEGER NOT NULL DEFAULT nextval('georitm.inventory_id_seq'::regclass),
  DTYPE VARCHAR(31),
  CONSTRAINT inventory_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.inventory IS 'Инвентория';
COMMENT ON COLUMN georitm.inventory.id IS 'Идентификатор инвентории';
COMMENT ON COLUMN georitm.inventory.DTYPE IS 'Тип/класс сущности';


ALTER SEQUENCE georitm.inventory_id_seq OWNED BY georitm.inventory.id;

CREATE TABLE georitm.guard_groups (
  id INTEGER NOT NULL,
  name VARCHAR(255) NOT NULL,
  parent_id INTEGER,
  CONSTRAINT guard_groups_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.guard_groups IS 'Группы ГБР';
COMMENT ON COLUMN georitm.guard_groups.id IS 'Идентификатор инвентории';
COMMENT ON COLUMN georitm.guard_groups.name IS 'Имя группы';
COMMENT ON COLUMN georitm.guard_groups.parent_id IS 'Родительская группа';


CREATE TABLE georitm.guarg_group_members (
  group_id INTEGER NOT NULL,
  guard_id INTEGER NOT NULL,
  CONSTRAINT guarg_group_members_pk PRIMARY KEY (group_id, guard_id)
);
COMMENT ON TABLE georitm.guarg_group_members IS 'ГБР в группах';
COMMENT ON COLUMN georitm.guarg_group_members.group_id IS 'Идентификатор инвентории';
COMMENT ON COLUMN georitm.guarg_group_members.guard_id IS 'Идентификатор ГБР';


CREATE TABLE georitm.zones_groups_wa (
  id INTEGER NOT NULL,
  zones_group_name VARCHAR(100) NOT NULL,
  ext_id INTEGER,
  parent_zones_group_id INTEGER,
  CONSTRAINT zones_groups_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.zones_groups_wa IS 'Группа зон';
COMMENT ON COLUMN georitm.zones_groups_wa.id IS 'Иденификатор группы зон';
COMMENT ON COLUMN georitm.zones_groups_wa.zones_group_name IS 'Имя группы';
COMMENT ON COLUMN georitm.zones_groups_wa.ext_id IS 'о импорта, потом может быть удален.';
COMMENT ON COLUMN georitm.zones_groups_wa.parent_zones_group_id IS 'Идентификатор родительской группы';


CREATE INDEX zones_groups_zones_groups_fk
  ON georitm.zones_groups_wa USING BTREE
  ( parent_zones_group_id ASC );

CREATE TABLE georitm.auth_roles_subord (
  senior_role_id INTEGER NOT NULL,
  junior_role_id INTEGER NOT NULL,
  CONSTRAINT auth_roles_subord_pk PRIMARY KEY (senior_role_id, junior_role_id)
);
COMMENT ON TABLE georitm.auth_roles_subord IS 'Иерархия ролей';
COMMENT ON COLUMN georitm.auth_roles_subord.senior_role_id IS 'Зарезервировано для иерархии ролей';
COMMENT ON COLUMN georitm.auth_roles_subord.junior_role_id IS 'Зарезервировано для иерархии ролей';


CREATE INDEX auth_roles_auth_roles_subord_fk1
  ON georitm.auth_roles_subord USING BTREE
  ( junior_role_id ASC );

CREATE TABLE georitm.zones (
  id INTEGER NOT NULL,
  zone_group_id INTEGER,
  name VARCHAR(100) NOT NULL,
  send_sms_to VARCHAR(1024),
  send_mail_to VARCHAR(1024),
  garage SMALLINT DEFAULT 0,
  ext_id INTEGER,
  type INTEGER NOT NULL,
  CONSTRAINT zones_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.zones IS 'Зона';
COMMENT ON COLUMN georitm.zones.id IS 'Идентификатор зоны';
COMMENT ON COLUMN georitm.zones.zone_group_id IS 'Идентификатор группы зон';
COMMENT ON COLUMN georitm.zones.name IS 'Имя зоны';
COMMENT ON COLUMN georitm.zones.send_sms_to IS 'Номера для отправки смс оповещений';
COMMENT ON COLUMN georitm.zones.send_mail_to IS 'Адреса для отправки оповещений';
COMMENT ON COLUMN georitm.zones.garage IS 'Является ли гаражом (не используется)';
COMMENT ON COLUMN georitm.zones.ext_id IS 'о импорта, потом может быть удален.';
COMMENT ON COLUMN georitm.zones.type IS 'Тип зоны';


CREATE INDEX zones_groups_zones_fk
  ON georitm.zones USING BTREE
  ( zone_group_id ASC );

CREATE SEQUENCE georitm.zone_rects_id_seq;

CREATE TABLE georitm.zone_rects (
  id INTEGER NOT NULL DEFAULT nextval('georitm.zone_rects_id_seq'::regclass),
  zone_id INTEGER NOT NULL,
  lat INTEGER NOT NULL,
  lon INTEGER NOT NULL,
  CONSTRAINT zone_rects_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.zone_rects IS 'Координаты полигона зоны';
COMMENT ON COLUMN georitm.zone_rects.id IS 'Идентификатор координаты';
COMMENT ON COLUMN georitm.zone_rects.zone_id IS 'Идентификатор зоны';
COMMENT ON COLUMN georitm.zone_rects.lat IS 'Широта';
COMMENT ON COLUMN georitm.zone_rects.lon IS 'Долгота';


ALTER SEQUENCE georitm.zone_rects_id_seq OWNED BY georitm.zone_rects.id;

CREATE SEQUENCE georitm.auth_actions_id_seq;

CREATE TABLE georitm.auth_actions (
  id INTEGER NOT NULL DEFAULT nextval('georitm.auth_actions_id_seq'::regclass),
  auth_action_code VARCHAR(50) NOT NULL,
  auth_action_name VARCHAR(100) NOT NULL,
  CONSTRAINT auth_actions_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.auth_actions IS 'Действия';
COMMENT ON COLUMN georitm.auth_actions.id IS 'Идентификатор действия';
COMMENT ON COLUMN georitm.auth_actions.auth_action_code IS 'Код действия';
COMMENT ON COLUMN georitm.auth_actions.auth_action_name IS 'Имя действия';


ALTER SEQUENCE georitm.auth_actions_id_seq OWNED BY georitm.auth_actions.id;

CREATE UNIQUE INDEX auth_actions_code_idx
  ON georitm.auth_actions
  ( auth_action_code );

CREATE TABLE georitm.auth_roles_actions (
  auth_role_id INTEGER NOT NULL,
  auth_action_id INTEGER NOT NULL,
  CONSTRAINT auth_roles_actions_pk PRIMARY KEY (auth_role_id, auth_action_id)
);
COMMENT ON TABLE georitm.auth_roles_actions IS 'Таблица связи';
COMMENT ON COLUMN georitm.auth_roles_actions.auth_role_id IS 'Идентификатор роли';
COMMENT ON COLUMN georitm.auth_roles_actions.auth_action_id IS 'Идентификатор действия';


CREATE INDEX auth_actions_auth_roles_actions_fk
  ON georitm.auth_roles_actions USING BTREE
  ( auth_action_id ASC );

CREATE SEQUENCE georitm.users_id_seq;

CREATE TABLE georitm.users (
  id INTEGER NOT NULL DEFAULT nextval('georitm.users_id_seq'::regclass),
  client_id INTEGER,
  username VARCHAR(255) NOT NULL,
  password VARCHAR(255) NOT NULL,
  full_name VARCHAR(255),
  phone VARCHAR(50),
  tm_key VARCHAR(50),
  access_constraint VARCHAR(255),
  ext_id INTEGER,
  owner_id INTEGER,
  exp_date TIMESTAMP,
  create_date TIMESTAMP,
  modify_date TIMESTAMP,
  change_password BOOLEAN,
  CONSTRAINT users_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.users IS 'Пользователь';
COMMENT ON COLUMN georitm.users.id IS 'Идентификатор пользователя';
COMMENT ON COLUMN georitm.users.client_id IS 'Идентификатор клиента';
COMMENT ON COLUMN georitm.users.username IS 'Имя пользователя';
COMMENT ON COLUMN georitm.users.password IS 'Пароль пользователя';
COMMENT ON COLUMN georitm.users.full_name IS 'ФИО пользователя';
COMMENT ON COLUMN georitm.users.phone IS 'Телефон';
COMMENT ON COLUMN georitm.users.tm_key IS 'Ключ touch memory';
COMMENT ON COLUMN georitm.users.access_constraint IS 'Идентификатор устройства. IMEI или IP или hostname.';
COMMENT ON COLUMN georitm.users.ext_id IS 'о импорта, потом может быть удален.';
COMMENT ON COLUMN georitm.users.owner_id IS 'Иденификатор владельца';
COMMENT ON COLUMN georitm.users.exp_date IS 'Окончание срока действия';
COMMENT ON COLUMN georitm.users.create_date IS 'Штамп времени создания';
COMMENT ON COLUMN georitm.users.modify_date IS 'Штамп времени изменения';
COMMENT ON COLUMN georitm.users.change_password IS 'Может ли изменять пароль (не используется)';


ALTER SEQUENCE georitm.users_id_seq OWNED BY georitm.users.id;

CREATE INDEX users_users_fk
  ON georitm.users USING BTREE
  ( owner_id ASC );

CREATE UNIQUE INDEX users_username_idx
  ON georitm.users
  ( username );

CREATE TABLE georitm.user_properties (
  user_id INTEGER NOT NULL,
  property_key VARCHAR(255) NOT NULL,
  property_value VARCHAR(2048) NOT NULL,
  CONSTRAINT user_properties_pk PRIMARY KEY (user_id, property_key)
);
COMMENT ON TABLE georitm.user_properties IS 'Дополнительные свойства пользователя';
COMMENT ON COLUMN georitm.user_properties.user_id IS 'Идентификатор пользователя';
COMMENT ON COLUMN georitm.user_properties.property_key IS 'Ключ';
COMMENT ON COLUMN georitm.user_properties.property_value IS 'Значение';


CREATE TABLE georitm.user_tokens (
  user_id INTEGER NOT NULL,
  token VARCHAR(64) NOT NULL,
  info VARCHAR(512),
  ts TIMESTAMP NOT NULL,
  CONSTRAINT user_tokens_pk PRIMARY KEY (user_id)
);
COMMENT ON TABLE georitm.user_tokens IS 'Токены для вхлдя пользователя в интерфейс администрирования';
COMMENT ON COLUMN georitm.user_tokens.user_id IS 'Идентификатор пользователя';
COMMENT ON COLUMN georitm.user_tokens.token IS 'токен';
COMMENT ON COLUMN georitm.user_tokens.info IS 'Дополнительные данные';
COMMENT ON COLUMN georitm.user_tokens.ts IS 'Таймстамп';


CREATE TABLE georitm.user_subscriptions (
  subscription_id VARCHAR(255) NOT NULL,
  user_id INTEGER NOT NULL,
  channel_id VARCHAR(64),
  locale VARCHAR(10),
  subscription_ts TIMESTAMP NOT NULL,
  sound VARCHAR(50) NOT NULL,
  CONSTRAINT user_subscriptions_pk PRIMARY KEY (subscription_id, user_id)
);
COMMENT ON TABLE georitm.user_subscriptions IS 'Подписки на push уведомления';
COMMENT ON COLUMN georitm.user_subscriptions.subscription_id IS 'Идентификатор подписки';
COMMENT ON COLUMN georitm.user_subscriptions.user_id IS 'Идентификатор пользователя';
COMMENT ON COLUMN georitm.user_subscriptions.channel_id IS 'Идентификатор канала OneSignal';
COMMENT ON COLUMN georitm.user_subscriptions.subscription_ts IS 'Таймстамп последней подписки';


CREATE SEQUENCE georitm.notifications_id_seq;

CREATE TABLE georitm.notifications (
  id INTEGER NOT NULL DEFAULT nextval('georitm.notifications_id_seq'::regclass),
  name VARCHAR(256) NOT NULL,
  is_active BOOLEAN NOT NULL,
  user_id INTEGER NOT NULL,
  def_locale VARCHAR(20),
  CONSTRAINT notifications_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.notifications IS 'Уведомления';
COMMENT ON COLUMN georitm.notifications.id IS 'Идентификатор уведомления';
COMMENT ON COLUMN georitm.notifications.name IS 'Имя уведомления';
COMMENT ON COLUMN georitm.notifications.is_active IS 'Включено';
COMMENT ON COLUMN georitm.notifications.user_id IS 'Идентификатор пользователя';
COMMENT ON COLUMN georitm.notifications.def_locale IS 'Язык сообщения';


ALTER SEQUENCE georitm.notifications_id_seq OWNED BY georitm.notifications.id;

CREATE SEQUENCE georitm.notification_addresses_id_seq;

CREATE TABLE georitm.notification_addresses (
  id INTEGER NOT NULL DEFAULT nextval('georitm.notification_addresses_id_seq'::regclass),
  address VARCHAR(128) NOT NULL,
  address_type CHAR(3) NOT NULL,
  notification_id INTEGER NOT NULL,
  CONSTRAINT notification_addresses_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.notification_addresses IS 'Адреса уведомлений';
COMMENT ON COLUMN georitm.notification_addresses.id IS 'Идентификатор адреса';
COMMENT ON COLUMN georitm.notification_addresses.address IS 'Адрес';
COMMENT ON COLUMN georitm.notification_addresses.address_type IS 'Тип адреса EML | SMS';
COMMENT ON COLUMN georitm.notification_addresses.notification_id IS 'Идентификатор уведомления';


ALTER SEQUENCE georitm.notification_addresses_id_seq OWNED BY georitm.notification_addresses.id;

CREATE SEQUENCE georitm.notification_alerts_id_seq;

CREATE TABLE georitm.notification_alerts (
  id INTEGER NOT NULL DEFAULT nextval('georitm.notification_alerts_id_seq'::regclass),
  alert_template_id INTEGER NOT NULL,
  notification_id INTEGER NOT NULL,
  CONSTRAINT notification_alerts_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.notification_alerts IS 'События уведомлений';
COMMENT ON COLUMN georitm.notification_alerts.id IS 'Идентификатор события';
COMMENT ON COLUMN georitm.notification_alerts.alert_template_id IS 'Идентификатор шаблона тревожного сообщения';
COMMENT ON COLUMN georitm.notification_alerts.notification_id IS 'Идентификатор уведомления';


ALTER SEQUENCE georitm.notification_alerts_id_seq OWNED BY georitm.notification_alerts.id;

CREATE SEQUENCE georitm.notification_alert_groups_id_seq;

CREATE TABLE georitm.notification_alert_groups (
  id INTEGER NOT NULL DEFAULT nextval('georitm.notification_alert_groups_id_seq'::regclass),
  alert_group_id INTEGER NOT NULL,
  notification_id INTEGER NOT NULL,
  CONSTRAINT notification_alert_groups_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.notification_alert_groups IS 'Группа событий';
COMMENT ON COLUMN georitm.notification_alert_groups.id IS 'Идентификатор';
COMMENT ON COLUMN georitm.notification_alert_groups.alert_group_id IS 'Идентификатор группы событий';
COMMENT ON COLUMN georitm.notification_alert_groups.notification_id IS 'Идентификатор уведомления';


ALTER SEQUENCE georitm.notification_alert_groups_id_seq OWNED BY georitm.notification_alert_groups.id;

CREATE TABLE georitm.scheduled_reports (
  uuid CHAR(36) NOT NULL,
  user_id INTEGER NOT NULL,
  info TEXT NOT NULL,
  CONSTRAINT scheduled_reports_pk PRIMARY KEY (uuid)
);
COMMENT ON TABLE georitm.scheduled_reports IS 'Расписание пользовательских отчетов';
COMMENT ON COLUMN georitm.scheduled_reports.uuid IS 'Идентификатор отчета';
COMMENT ON COLUMN georitm.scheduled_reports.user_id IS 'Идентификатор пользователя';
COMMENT ON COLUMN georitm.scheduled_reports.info IS 'Информация по отчету';


CREATE SEQUENCE georitm.staff_id_seq;

CREATE TABLE georitm.staff (
  id INTEGER NOT NULL DEFAULT nextval('georitm.staff_id_seq'::regclass),
  fname VARCHAR(255) NOT NULL,
  lname VARCHAR(255) NOT NULL,
  mname VARCHAR(255) NOT NULL,
  phone VARCHAR(50) NOT NULL,
  user_id INTEGER NOT NULL,
  position_id INTEGER NOT NULL,
  is_deleted BOOLEAN DEFAULT false NOT NULL,
  CONSTRAINT staff_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.staff IS 'Сотрудники';
COMMENT ON COLUMN georitm.staff.id IS 'Идентификатор сотрудника';
COMMENT ON COLUMN georitm.staff.fname IS 'Имя';
COMMENT ON COLUMN georitm.staff.lname IS 'Фамилия';
COMMENT ON COLUMN georitm.staff.mname IS 'Отчество';
COMMENT ON COLUMN georitm.staff.phone IS 'Телефон сотрудника';
COMMENT ON COLUMN georitm.staff.user_id IS 'Идентификатор пользователя';
COMMENT ON COLUMN georitm.staff.position_id IS 'Идентификатор должности';
COMMENT ON COLUMN georitm.staff.is_deleted IS 'Флаг удаления';


ALTER SEQUENCE georitm.staff_id_seq OWNED BY georitm.staff.id;

CREATE SEQUENCE georitm.users_groups_id_seq;

CREATE TABLE georitm.users_groups (
  id INTEGER NOT NULL DEFAULT nextval('georitm.users_groups_id_seq'::regclass),
  client_id INTEGER NOT NULL,
  user_group_name VARCHAR(50) NOT NULL,
  parent_users_group_id INTEGER,
  owner_id INTEGER NOT NULL,
  CONSTRAINT users_groups_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.users_groups IS 'Группа пользователей';
COMMENT ON COLUMN georitm.users_groups.id IS 'Идентификатор группы';
COMMENT ON COLUMN georitm.users_groups.client_id IS 'Идентификатор клиента';
COMMENT ON COLUMN georitm.users_groups.user_group_name IS 'Имя группы';
COMMENT ON COLUMN georitm.users_groups.parent_users_group_id IS 'Идентификатор родительской группы';
COMMENT ON COLUMN georitm.users_groups.owner_id IS 'Идентификатор пользователя владельца группы';


ALTER SEQUENCE georitm.users_groups_id_seq OWNED BY georitm.users_groups.id;

CREATE INDEX users_users_groups_fk
  ON georitm.users_groups USING BTREE
  ( owner_id ASC );

CREATE INDEX users_groups_users_groups_fk
  ON georitm.users_groups USING BTREE
  ( parent_users_group_id ASC );

CREATE TABLE georitm.auth_users_actions (
  user_id INTEGER NOT NULL,
  auth_action_id INTEGER NOT NULL,
  CONSTRAINT auth_users_actions_pk PRIMARY KEY (user_id, auth_action_id)
);
COMMENT ON TABLE georitm.auth_users_actions IS 'Таблица связи';
COMMENT ON COLUMN georitm.auth_users_actions.user_id IS 'Идентификатор пользователя';
COMMENT ON COLUMN georitm.auth_users_actions.auth_action_id IS 'Идентификатор действия';


CREATE INDEX auth_actions_auth_users_actions_fk
  ON georitm.auth_users_actions USING BTREE
  ( auth_action_id ASC );

CREATE TABLE georitm.auth_map (
  inventory_id INTEGER NOT NULL,
  user_id INTEGER NOT NULL,
  CONSTRAINT auth_map_pk PRIMARY KEY (inventory_id, user_id)
);
COMMENT ON TABLE georitm.auth_map IS 'Таблица связи';
COMMENT ON COLUMN georitm.auth_map.inventory_id IS 'Идентификатор инвентории';
COMMENT ON COLUMN georitm.auth_map.user_id IS 'Идентификатор пользолвателя';


CREATE INDEX users_auth_map_fk
  ON georitm.auth_map USING BTREE
  ( user_id ASC );

CREATE TABLE georitm.users_roles (
  user_id INTEGER NOT NULL,
  auth_role_id INTEGER NOT NULL,
  CONSTRAINT users_roles_pk PRIMARY KEY (user_id, auth_role_id)
);
COMMENT ON TABLE georitm.users_roles IS 'Таблица связи';
COMMENT ON COLUMN georitm.users_roles.user_id IS 'Идентификатор пользователя';
COMMENT ON COLUMN georitm.users_roles.auth_role_id IS 'Иденитификатор роли';


CREATE INDEX auth_roles_users_roles_fk
  ON georitm.users_roles USING BTREE
  ( auth_role_id ASC );

CREATE TABLE georitm.users_users_groups_map (
  user_id INTEGER NOT NULL,
  users_group_id INTEGER NOT NULL,
  CONSTRAINT users_users_groups_map_pk PRIMARY KEY (user_id, users_group_id)
);
COMMENT ON TABLE georitm.users_users_groups_map IS 'Таблица связи';
COMMENT ON COLUMN georitm.users_users_groups_map.user_id IS 'Идентификатор пользователя';
COMMENT ON COLUMN georitm.users_users_groups_map.users_group_id IS 'Идентификатор группы пользователей';


CREATE INDEX users_groups_users_users_groups_map_fk
  ON georitm.users_users_groups_map USING BTREE
  ( users_group_id ASC );

CREATE SEQUENCE georitm.parameter_types_id_seq;

CREATE TABLE georitm.parameter_types (
  id INTEGER NOT NULL DEFAULT nextval('georitm.parameter_types_id_seq'::regclass),
  name VARCHAR(255) NOT NULL,
  code VARCHAR(50) NOT NULL,
  CONSTRAINT parameter_types_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.parameter_types IS 'Тип параметра объекта';
COMMENT ON COLUMN georitm.parameter_types.id IS 'Идентификатор параметра';
COMMENT ON COLUMN georitm.parameter_types.name IS 'Имя';
COMMENT ON COLUMN georitm.parameter_types.code IS 'Мнемонический код';


ALTER SEQUENCE georitm.parameter_types_id_seq OWNED BY georitm.parameter_types.id;

CREATE TABLE georitm.object_groups (
  id INTEGER NOT NULL,
  name VARCHAR(255) NOT NULL,
  group_type SMALLINT DEFAULT 0 NOT NULL,
  ext_id INTEGER,
  parent_id INTEGER,
  CONSTRAINT object_groups_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.object_groups IS 'Группа объектов';
COMMENT ON COLUMN georitm.object_groups.id IS 'Идентификатор группы объектов';
COMMENT ON COLUMN georitm.object_groups.name IS 'Имя группы';
COMMENT ON COLUMN georitm.object_groups.group_type IS 'ых объектов...';
COMMENT ON COLUMN georitm.object_groups.ext_id IS 'о импорта, потом может быть удален.';
COMMENT ON COLUMN georitm.object_groups.parent_id IS 'Родительская группа';


CREATE TABLE georitm.object_groups_zone_groups (
  object_group_id INTEGER NOT NULL,
  zone_group_id INTEGER NOT NULL,
  CONSTRAINT object_groups_zone_groups_pk PRIMARY KEY (object_group_id, zone_group_id)
);
COMMENT ON TABLE georitm.object_groups_zone_groups IS 'Привязка контроля посещения зон к группам объектов';
COMMENT ON COLUMN georitm.object_groups_zone_groups.object_group_id IS 'Идентификатор группы объектов';
COMMENT ON COLUMN georitm.object_groups_zone_groups.zone_group_id IS 'Иденификатор группы зон';


CREATE SEQUENCE georitm.notification_groups_id_seq;

CREATE TABLE georitm.notification_groups (
  id INTEGER NOT NULL DEFAULT nextval('georitm.notification_groups_id_seq'::regclass),
  object_group_id INTEGER NOT NULL,
  notification_id INTEGER NOT NULL,
  CONSTRAINT notification_groups_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.notification_groups IS 'Группы уведомлений';
COMMENT ON COLUMN georitm.notification_groups.id IS 'Идентификатор группы уведомлений';
COMMENT ON COLUMN georitm.notification_groups.object_group_id IS 'Идентификатор группы объектов';
COMMENT ON COLUMN georitm.notification_groups.notification_id IS 'Идентификатор уведомления';


ALTER SEQUENCE georitm.notification_groups_id_seq OWNED BY georitm.notification_groups.id;

CREATE SEQUENCE georitm.object_types_id_seq;

CREATE TABLE georitm.object_types (
  id INTEGER NOT NULL DEFAULT nextval('georitm.object_types_id_seq'::regclass),
  name VARCHAR(255) NOT NULL,
  code VARCHAR(10) NOT NULL,
  CONSTRAINT object_types_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.object_types IS 'Тип объекта';
COMMENT ON COLUMN georitm.object_types.id IS 'Идентификатор типа объекта';
COMMENT ON COLUMN georitm.object_types.name IS 'Название типа';
COMMENT ON COLUMN georitm.object_types.code IS 'Мнемонический код';


ALTER SEQUENCE georitm.object_types_id_seq OWNED BY georitm.object_types.id;

CREATE TABLE georitm.object_type_parameters (
  object_type_id INTEGER NOT NULL,
  parameter_type_id INTEGER NOT NULL,
  CONSTRAINT object_type_parameters_pk PRIMARY KEY (object_type_id, parameter_type_id)
);
COMMENT ON TABLE georitm.object_type_parameters IS 'Параметры в зависимости от типа';
COMMENT ON COLUMN georitm.object_type_parameters.object_type_id IS 'Идентификатор типа объекта';
COMMENT ON COLUMN georitm.object_type_parameters.parameter_type_id IS 'Идентификатор параметра';


CREATE TABLE georitm.objects (
  id INTEGER NOT NULL,
  type_id INTEGER,
  name VARCHAR(255) NOT NULL,
  rev VARCHAR(50),
  import_ts TIMESTAMP,
  ext_id INTEGER NOT NULL,
  data_source_id CHAR(36),
  imei BIGINT,
  alarm_ts TIMESTAMP,
  alert_ts TIMESTAMP,
  alarm_state SMALLINT DEFAULT 0 NOT NULL,
  CONSTRAINT objects_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.objects IS 'Объект наблюдения';
COMMENT ON COLUMN georitm.objects.id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm.objects.type_id IS 'Ссылка на тип объека';
COMMENT ON COLUMN georitm.objects.name IS 'Название объекта';
COMMENT ON COLUMN georitm.objects.rev IS 'Ревизия объектап';
COMMENT ON COLUMN georitm.objects.import_ts IS 'Штамп времени последнего обновления данных';
COMMENT ON COLUMN georitm.objects.ext_id IS 'о импорта, потом может быть удален.';
COMMENT ON COLUMN georitm.objects.imei IS 'IMEI объекта';
COMMENT ON COLUMN georitm.objects.alarm_ts IS 'Время последней тревоги';
COMMENT ON COLUMN georitm.objects.alert_ts IS 'Время последнего события';
COMMENT ON COLUMN georitm.objects.alarm_state IS 'Состояние тревоги';


CREATE INDEX object_ext_id_idx
  ON georitm.objects
  ( ext_id );

CREATE UNIQUE INDEX objects_imei_idx
  ON georitm.objects
  ( imei );

CREATE TABLE georitm.expense_details (
  account_uuid VARCHAR(36) NOT NULL,
  ts TIMESTAMP NOT NULL,
  object_id INTEGER NOT NULL,
  CONSTRAINT expense_details_pk PRIMARY KEY (account_uuid, ts, object_id)
);
COMMENT ON TABLE georitm.expense_details IS 'Детализация списания';
COMMENT ON COLUMN georitm.expense_details.account_uuid IS 'Идентификатор счета';
COMMENT ON COLUMN georitm.expense_details.ts IS 'Время';
COMMENT ON COLUMN georitm.expense_details.object_id IS 'Идентификатор объекта';


CREATE TABLE georitm.object_status (
  object_id INTEGER NOT NULL,
  status INTEGER DEFAULT 0 NOT NULL,
  prev_status INTEGER,
  service_ts TIMESTAMP,
  CONSTRAINT object_status_pk PRIMARY KEY (object_id)
);
COMMENT ON COLUMN georitm.object_status.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm.object_status.status IS 'Текущий статус';
COMMENT ON COLUMN georitm.object_status.prev_status IS 'Предидущий статус';
COMMENT ON COLUMN georitm.object_status.service_ts IS 'Штамп времени завершения статуса сервис';


CREATE SEQUENCE georitm.object_status_history_id_seq;

CREATE TABLE georitm.object_status_history (
  id INTEGER NOT NULL DEFAULT nextval('georitm.object_status_history_id_seq'::regclass),
  object_id INTEGER NOT NULL,
  status INTEGER NOT NULL,
  prev_status INTEGER,
  transition_ts TIMESTAMP NOT NULL,
  CONSTRAINT object_status_history_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.object_status_history IS 'История изменения статуса объекта';
COMMENT ON COLUMN georitm.object_status_history.id IS 'Первичный ключ';
COMMENT ON COLUMN georitm.object_status_history.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm.object_status_history.status IS 'Статус, в который осуществлен перевод';
COMMENT ON COLUMN georitm.object_status_history.prev_status IS 'Cтатус, из которог осуществлен перевод';
COMMENT ON COLUMN georitm.object_status_history.transition_ts IS 'Таймстамп статусного перевода';


ALTER SEQUENCE georitm.object_status_history_id_seq OWNED BY georitm.object_status_history.id;

CREATE INDEX object_status_history_obj_id_ts_idx
  ON georitm.object_status_history
  ( object_id, transition_ts );

CREATE TABLE georitm.object_guards (
  object_id INTEGER NOT NULL,
  guard_id INTEGER NOT NULL,
  CONSTRAINT object_guards_pk PRIMARY KEY (object_id, guard_id)
);
COMMENT ON TABLE georitm.object_guards IS 'Привязка ГБР к объектам';
COMMENT ON COLUMN georitm.object_guards.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm.object_guards.guard_id IS 'Идентификатор ГБР';


CREATE SEQUENCE georitm.guard_calls_id_seq;

CREATE TABLE georitm.guard_calls (
  id INTEGER NOT NULL DEFAULT nextval('georitm.guard_calls_id_seq'::regclass),
  user_id INTEGER NOT NULL,
  object_id INTEGER NOT NULL,
  guard_id INTEGER NOT NULL,
  call_ts TIMESTAMP NOT NULL,
  accepted_at TIMESTAMP,
  done_ts TIMESTAMP,
  done_code INTEGER,
  arrived_at TIMESTAMP,
  CONSTRAINT guard_calls_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.guard_calls IS 'Вызовы ГБР';
COMMENT ON COLUMN georitm.guard_calls.user_id IS 'Идентификатор пользователя';
COMMENT ON COLUMN georitm.guard_calls.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm.guard_calls.guard_id IS 'Идентификатор ГБР';
COMMENT ON COLUMN georitm.guard_calls.call_ts IS 'Время вызова';
COMMENT ON COLUMN georitm.guard_calls.accepted_at IS 'Время приема';
COMMENT ON COLUMN georitm.guard_calls.done_ts IS 'Время завершения';
COMMENT ON COLUMN georitm.guard_calls.done_code IS 'Код завершения';
COMMENT ON COLUMN georitm.guard_calls.arrived_at IS 'Время прибытия на объект';


ALTER SEQUENCE georitm.guard_calls_id_seq OWNED BY georitm.guard_calls.id;

CREATE INDEX guard_calls_ts_idx
  ON georitm.guard_calls
  ( call_ts );

CREATE SEQUENCE georitm.object_alert_log_id_seq;

CREATE TABLE georitm.object_alert_log (
  id BIGINT NOT NULL DEFAULT nextval('georitm.object_alert_log_id_seq'::regclass),
  object_id INTEGER NOT NULL,
  action_ts TIMESTAMP NOT NULL,
  user_id INTEGER NOT NULL,
  action_type SMALLINT NOT NULL,
  comment VARCHAR(4096) NOT NULL,
  CONSTRAINT object_alert_log_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.object_alert_log IS 'Тревогжный статус объекта';
COMMENT ON COLUMN georitm.object_alert_log.id IS 'Суррогатный ключ';
COMMENT ON COLUMN georitm.object_alert_log.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm.object_alert_log.action_ts IS 'Время совершения действия';
COMMENT ON COLUMN georitm.object_alert_log.user_id IS 'Идентификатор пользователя';
COMMENT ON COLUMN georitm.object_alert_log.action_type IS 'Тип действия';
COMMENT ON COLUMN georitm.object_alert_log.comment IS 'Комментарий';


ALTER SEQUENCE georitm.object_alert_log_id_seq OWNED BY georitm.object_alert_log.id;

CREATE INDEX object_alert_log_idx
  ON georitm.object_alert_log
  ( object_id, action_ts );

CREATE INDEX object_alert_log_obj_ts_idx
  ON georitm.object_alert_log
  ( object_id, action_ts );

CREATE TABLE georitm.zone_control (
  object_id INTEGER NOT NULL,
  zone_id INTEGER NOT NULL,
  CONSTRAINT zone_control_pk PRIMARY KEY (object_id, zone_id)
);
COMMENT ON TABLE georitm.zone_control IS 'Контроль входа/выхода объекта в зону/из зоны';
COMMENT ON COLUMN georitm.zone_control.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm.zone_control.zone_id IS 'Идентификатор зоны';


CREATE SEQUENCE georitm.notification_objects_id_seq;

CREATE TABLE georitm.notification_objects (
  id INTEGER NOT NULL DEFAULT nextval('georitm.notification_objects_id_seq'::regclass),
  object_id INTEGER NOT NULL,
  notification_id INTEGER NOT NULL,
  CONSTRAINT notification_objects_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.notification_objects IS 'Объекты для нотификации';
COMMENT ON COLUMN georitm.notification_objects.id IS 'Идентификатор записи об объекте уведомления';
COMMENT ON COLUMN georitm.notification_objects.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm.notification_objects.notification_id IS 'Идентификатор уведомления';


ALTER SEQUENCE georitm.notification_objects_id_seq OWNED BY georitm.notification_objects.id;

CREATE SEQUENCE georitm.notification_areas_id_seq;

CREATE TABLE georitm.notification_areas (
  id INTEGER NOT NULL DEFAULT nextval('georitm.notification_areas_id_seq'::regclass),
  num INTEGER NOT NULL,
  notification_object_id INTEGER NOT NULL,
  CONSTRAINT notification_areas_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.notification_areas IS 'Разделы уведомлений';
COMMENT ON COLUMN georitm.notification_areas.id IS 'Идентификатор раздела уведомлений';
COMMENT ON COLUMN georitm.notification_areas.num IS 'Номер раздела';
COMMENT ON COLUMN georitm.notification_areas.notification_object_id IS 'Идентификатор объекта уведомления';


ALTER SEQUENCE georitm.notification_areas_id_seq OWNED BY georitm.notification_areas.id;

CREATE SEQUENCE georitm.notification_zones_id_seq;

CREATE TABLE georitm.notification_zones (
  id INTEGER NOT NULL DEFAULT nextval('georitm.notification_zones_id_seq'::regclass),
  num INTEGER NOT NULL,
  notificaton_area_id INTEGER NOT NULL,
  CONSTRAINT notification_zones_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.notification_zones IS 'Зоны уведомлений';
COMMENT ON COLUMN georitm.notification_zones.id IS 'Идентификатор зоны уведомлений';
COMMENT ON COLUMN georitm.notification_zones.num IS 'Номер зоны';
COMMENT ON COLUMN georitm.notification_zones.notificaton_area_id IS 'Идентификатор раздела';


ALTER SEQUENCE georitm.notification_zones_id_seq OWNED BY georitm.notification_zones.id;

CREATE SEQUENCE georitm.pictures_id_seq;

CREATE TABLE georitm.pictures (
  id INTEGER NOT NULL DEFAULT nextval('georitm.pictures_id_seq'::regclass),
  file_name VARCHAR(1024) NOT NULL,
  object_id INTEGER NOT NULL,
  mime_type VARCHAR(256) NOT NULL,
  caption VARCHAR(256),
  payload BYTEA NOT NULL,
  CONSTRAINT pictures_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.pictures IS 'Фото/планы объекта';
COMMENT ON COLUMN georitm.pictures.id IS 'Идентификатор картинки';
COMMENT ON COLUMN georitm.pictures.file_name IS 'Имя файла';
COMMENT ON COLUMN georitm.pictures.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm.pictures.mime_type IS 'Тип MIME';
COMMENT ON COLUMN georitm.pictures.caption IS 'Подпись';
COMMENT ON COLUMN georitm.pictures.payload IS 'Данные картинки';


ALTER SEQUENCE georitm.pictures_id_seq OWNED BY georitm.pictures.id;

CREATE SEQUENCE georitm.object_areas_id_seq;

CREATE TABLE georitm.object_areas (
  id INTEGER NOT NULL DEFAULT nextval('georitm.object_areas_id_seq'::regclass),
  object_id INTEGER NOT NULL,
  name VARCHAR(255),
  num INTEGER NOT NULL,
  comment VARCHAR(2048),
  is_guarded BOOLEAN DEFAULT false NOT NULL,
  version INTEGER NOT NULL,
  in_alarm BOOLEAN DEFAULT false NOT NULL,
  CONSTRAINT object_areas_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.object_areas IS 'Разделы охраны';
COMMENT ON COLUMN georitm.object_areas.id IS 'Идентификатор раздела';
COMMENT ON COLUMN georitm.object_areas.object_id IS 'Ижентификатор объекта';
COMMENT ON COLUMN georitm.object_areas.name IS 'Название раэдела';
COMMENT ON COLUMN georitm.object_areas.num IS 'Номер раздела';
COMMENT ON COLUMN georitm.object_areas.comment IS 'Примечания';
COMMENT ON COLUMN georitm.object_areas.is_guarded IS 'Находится под охраной';
COMMENT ON COLUMN georitm.object_areas.version IS 'Версия записи';
COMMENT ON COLUMN georitm.object_areas.in_alarm IS 'Наличие тревоги по разделу';


ALTER SEQUENCE georitm.object_areas_id_seq OWNED BY georitm.object_areas.id;

CREATE UNIQUE INDEX object_areas_obj_id_num_idx
  ON georitm.object_areas
  ( object_id, num );

CREATE TABLE georitm.object_area_roles (
  area_id INTEGER NOT NULL,
  role_code VARCHAR(20) NOT NULL,
  CONSTRAINT object_area_roles_pk PRIMARY KEY (area_id, role_code)
);
COMMENT ON TABLE georitm.object_area_roles IS 'Разрешенные к управлению разделом роли';
COMMENT ON COLUMN georitm.object_area_roles.area_id IS 'Идентификатор раздела';
COMMENT ON COLUMN georitm.object_area_roles.role_code IS 'Код роли';


CREATE SEQUENCE georitm.area_zones_id_seq;

CREATE TABLE georitm.area_zones (
  id INTEGER NOT NULL DEFAULT nextval('georitm.area_zones_id_seq'::regclass),
  area_id INTEGER NOT NULL,
  name VARCHAR(255),
  num INTEGER NOT NULL,
  in_alarm BOOLEAN DEFAULT false NOT NULL,
  comment VARCHAR(2048),
  version INTEGER DEFAULT 1 NOT NULL,
  CONSTRAINT area_zones_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.area_zones IS 'Зоны охраны разделов';
COMMENT ON COLUMN georitm.area_zones.id IS 'Идентификатор зоны охраны';
COMMENT ON COLUMN georitm.area_zones.area_id IS 'Идентификатор раздела';
COMMENT ON COLUMN georitm.area_zones.name IS 'Название зоны';
COMMENT ON COLUMN georitm.area_zones.num IS 'Номер зоны';
COMMENT ON COLUMN georitm.area_zones.in_alarm IS 'Наличие тревог по зоне';
COMMENT ON COLUMN georitm.area_zones.comment IS 'Примечаниz';
COMMENT ON COLUMN georitm.area_zones.version IS 'Версия записи';


ALTER SEQUENCE georitm.area_zones_id_seq OWNED BY georitm.area_zones.id;

CREATE UNIQUE INDEX area_zones_area_id_num_idx
  ON georitm.area_zones
  ( area_id, num );

CREATE TABLE georitm.area_zone_faults (
  area_zone_id INTEGER NOT NULL,
  fault_code INTEGER NOT NULL,
  alert_message_id INTEGER,
  CONSTRAINT area_zone_faults_pk PRIMARY KEY (area_zone_id, fault_code)
);
COMMENT ON TABLE georitm.area_zone_faults IS 'Ошибки по зоне';
COMMENT ON COLUMN georitm.area_zone_faults.area_zone_id IS 'Идентификатор зоны охраны';
COMMENT ON COLUMN georitm.area_zone_faults.fault_code IS 'Код ошибки';
COMMENT ON COLUMN georitm.area_zone_faults.alert_message_id IS 'Идентификатор сообщения';


CREATE SEQUENCE georitm.object_alerts_id_seq;

CREATE TABLE georitm.object_alerts (
  id BIGINT NOT NULL DEFAULT nextval('georitm.object_alerts_id_seq'::regclass),
  alert_ts TIMESTAMP NOT NULL,
  recived_at TIMESTAMP NOT NULL,
  is_alarm BOOLEAN NOT NULL,
  alert_message_id INTEGER NOT NULL,
  area INTEGER NOT NULL,
  area_zone INT,
  object_id INTEGER NOT NULL,
  group_name VARCHAR(255),
  closed_at TIMESTAMP,
  close_comment VARCHAR(4096),
  ext_id INTEGER,
  info VARCHAR(255),
  CONSTRAINT object_alerts_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.object_alerts IS 'Тревоги по объектам';
COMMENT ON COLUMN georitm.object_alerts.id IS 'Идентификатор тревоги';
COMMENT ON COLUMN georitm.object_alerts.alert_ts IS 'Время события в приборе';
COMMENT ON COLUMN georitm.object_alerts.recived_at IS 'Время получения сервером';
COMMENT ON COLUMN georitm.object_alerts.is_alarm IS 'Яаляется ли тревогой';
COMMENT ON COLUMN georitm.object_alerts.alert_message_id IS 'Идентификатор типового сообщения';
COMMENT ON COLUMN georitm.object_alerts.area IS 'Раздел';
COMMENT ON COLUMN georitm.object_alerts.area_zone IS 'Зона раздела';
COMMENT ON COLUMN georitm.object_alerts.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm.object_alerts.group_name IS 'Имя группы событий';
COMMENT ON COLUMN georitm.object_alerts.closed_at IS 'Штамп времени закрытия тревоги';
COMMENT ON COLUMN georitm.object_alerts.close_comment IS 'Комментарий при закрытии';
COMMENT ON COLUMN georitm.object_alerts.ext_id IS 'о импорта, потом может быть удален.';
COMMENT ON COLUMN georitm.object_alerts.info IS 'Дополнительная информация';


ALTER SEQUENCE georitm.object_alerts_id_seq OWNED BY georitm.object_alerts.id;

CREATE INDEX object_alerts_ts_idx
  ON georitm.object_alerts
  ( alert_ts );

CREATE INDEX object_alerts_ts_objectid_idx
  ON georitm.object_alerts
  ( alert_ts, object_id );

CREATE INDEX object_alerts_received_at_idx
  ON georitm.object_alerts
  ( recived_at );

CREATE INDEX object_received_at_objectid_idx
  ON georitm.object_alerts
  ( recived_at, object_id );

CREATE INDEX object_alerts_closed_alarms
  ON georitm.object_alerts
  ( is_alarm, closed_at );

CREATE INDEX object_alerts_ext_id_idx
  ON georitm.object_alerts
  ( ext_id );

CREATE TABLE georitm.alert_channel_info (
  alert_id BIGINT NOT NULL,
  channel_name VARCHAR(500),
  CONSTRAINT alert_channel_info_pk PRIMARY KEY (alert_id)
);
COMMENT ON TABLE georitm.alert_channel_info IS 'Входящий поток тревоги';
COMMENT ON COLUMN georitm.alert_channel_info.alert_id IS 'Идентификатор тревоги';
COMMENT ON COLUMN georitm.alert_channel_info.channel_name IS 'Наименование входящего потока';


CREATE SEQUENCE georitm.alerts_log_id_seq;

CREATE TABLE georitm.alerts_log (
  id BIGINT NOT NULL DEFAULT nextval('georitm.alerts_log_id_seq'::regclass),
  alert_id BIGINT NOT NULL,
  log_ts TIMESTAMP NOT NULL,
  log_comment VARCHAR(4096) NOT NULL,
  user_id INTEGER NOT NULL,
  CONSTRAINT alerts_log_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.alerts_log IS 'Журнал событий';
COMMENT ON COLUMN georitm.alerts_log.id IS 'Идентификатор записи в журнале';
COMMENT ON COLUMN georitm.alerts_log.alert_id IS 'Идентификатор события';
COMMENT ON COLUMN georitm.alerts_log.log_ts IS 'Время записи';
COMMENT ON COLUMN georitm.alerts_log.log_comment IS 'Комментарий';
COMMENT ON COLUMN georitm.alerts_log.user_id IS 'Идентификатор пользователя';


ALTER SEQUENCE georitm.alerts_log_id_seq OWNED BY georitm.alerts_log.id;

CREATE TABLE georitm.clear_route_tasks (
  object_id INTEGER NOT NULL,
  date_from TIMESTAMP NOT NULL,
  date_to TIMESTAMP,
  CONSTRAINT clear_route_tasks_pk PRIMARY KEY (object_id, date_from)
);
COMMENT ON TABLE georitm.clear_route_tasks IS 'Задания на очистку данных по объектам';
COMMENT ON COLUMN georitm.clear_route_tasks.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm.clear_route_tasks.date_from IS 'Дата С';
COMMENT ON COLUMN georitm.clear_route_tasks.date_to IS 'Дата По';


CREATE TABLE georitm.schedule (
  staff_id INTEGER NOT NULL,
  object_id INTEGER NOT NULL,
  date_from TIMESTAMP NOT NULL,
  date_to TIMESTAMP NOT NULL,
  CONSTRAINT schedule_pk PRIMARY KEY (staff_id, object_id, date_from)
);
COMMENT ON TABLE georitm.schedule IS 'Расписание смен';
COMMENT ON COLUMN georitm.schedule.staff_id IS 'Идентификатор сотрудника';
COMMENT ON COLUMN georitm.schedule.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm.schedule.date_from IS 'Начало смены';
COMMENT ON COLUMN georitm.schedule.date_to IS 'Окончание смены';


CREATE INDEX schedule_idx
  ON georitm.schedule
  ( date_to );

CREATE SEQUENCE georitm.object_group_history_id_seq;

CREATE TABLE georitm.object_group_history (
  id INTEGER NOT NULL DEFAULT nextval('georitm.object_group_history_id_seq'::regclass),
  object_id INTEGER NOT NULL,
  from_group_id INTEGER NOT NULL,
  to_group_id INTEGER NOT NULL,
  operation_ts TIMESTAMP NOT NULL,
  ext_id INTEGER NOT NULL,
  CONSTRAINT object_group_history_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.object_group_history IS 'Таблица истории размещения объектов в группах';
COMMENT ON COLUMN georitm.object_group_history.id IS 'Суррогатный ключ записи.';
COMMENT ON COLUMN georitm.object_group_history.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm.object_group_history.from_group_id IS 'Идентификатор группы объектов';
COMMENT ON COLUMN georitm.object_group_history.to_group_id IS 'Идентификатор группы объектов';
COMMENT ON COLUMN georitm.object_group_history.operation_ts IS 'Время совершения операции';
COMMENT ON COLUMN georitm.object_group_history.ext_id IS 'о импорта, потом может быть удален.';


ALTER SEQUENCE georitm.object_group_history_id_seq OWNED BY georitm.object_group_history.id;

CREATE SEQUENCE georitm.calibrations_id_seq;

CREATE TABLE georitm.calibrations (
  id INTEGER NOT NULL DEFAULT nextval('georitm.calibrations_id_seq'::regclass),
  object_id INTEGER NOT NULL,
  parameter_id INTEGER NOT NULL,
  analogue DOUBLE PRECISION NOT NULL,
  litre DOUBLE PRECISION NOT NULL,
  CONSTRAINT calibrations_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.calibrations IS 'Тарировочная таблица';
COMMENT ON COLUMN georitm.calibrations.id IS 'Идентификатор тарировочной таблицы';
COMMENT ON COLUMN georitm.calibrations.analogue IS 'Знаячение аналогового датчика';
COMMENT ON COLUMN georitm.calibrations.litre IS 'Объем';


ALTER SEQUENCE georitm.calibrations_id_seq OWNED BY georitm.calibrations.id;

CREATE TABLE georitm.object_settings (
  object_id INTEGER NOT NULL,
  settings_key VARCHAR(100) NOT NULL,
  value TEXT NOT NULL,
  CONSTRAINT object_settings_pk PRIMARY KEY (object_id, settings_key)
);
COMMENT ON TABLE georitm.object_settings IS 'Настройки объекта';
COMMENT ON COLUMN georitm.object_settings.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm.object_settings.settings_key IS 'Имя параметра, ключ в ассоциятивном массиве';
COMMENT ON COLUMN georitm.object_settings.value IS 'Значение параметра';


CREATE TABLE georitm.object_group_members (
  group_id INTEGER NOT NULL,
  object_id INTEGER NOT NULL,
  CONSTRAINT object_group_members_pk PRIMARY KEY (group_id, object_id)
);
COMMENT ON TABLE georitm.object_group_members IS 'Объекты в группе';
COMMENT ON COLUMN georitm.object_group_members.group_id IS 'Идентификатор группы объектов';
COMMENT ON COLUMN georitm.object_group_members.object_id IS 'Идентификатор объекта';


CREATE SEQUENCE georitm.panic_button_control_id_seq;

CREATE TABLE georitm.panic_button_control (
                id INTEGER NOT NULL DEFAULT nextval('georitm.panic_button_control_id_seq'::regclass),
                object_id INTEGER NOT NULL,
                start_ts TIMESTAMP NOT NULL,
                end_ts TIMESTAMP NOT NULL,
                type SMALLINT NOT NULL,
                result SMALLINT NOT NULL,
                area_num INTEGER,
                zone_num INTEGER,
                CONSTRAINT panic_button_control_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm.panic_button_control IS 'Контроль Кнопки тревожной сингнализации (КТС)';
COMMENT ON COLUMN georitm.panic_button_control.id IS 'Идентификатор';
COMMENT ON COLUMN georitm.panic_button_control.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm.panic_button_control.start_ts IS 'Штамп времени начала проверки';
COMMENT ON COLUMN georitm.panic_button_control.end_ts IS 'Штамп времени окончания проверки';
COMMENT ON COLUMN georitm.panic_button_control.type IS 'Тип проверки КТС (автоматическая/ручная)';
COMMENT ON COLUMN georitm.panic_button_control.result IS 'Результат проверки КТС';
COMMENT ON COLUMN georitm.panic_button_control.area_num IS 'Номер раздела по которому поступило тревожное событие';
COMMENT ON COLUMN georitm.panic_button_control.zone_num IS 'Номер зоны по которой поступило тревожное событие';

ALTER SEQUENCE georitm.panic_button_control_id_seq OWNED BY georitm.panic_button_control.id;

CREATE INDEX object_id_start_ts_end_ts
 ON georitm.panic_button_control
 ( object_id, start_ts, end_ts );

ALTER TABLE georitm.panic_button_control ADD CONSTRAINT objects_panic_button_control_fk
FOREIGN KEY (object_id)
REFERENCES georitm.objects (id)
ON DELETE CASCADE
ON UPDATE NO ACTION
NOT DEFERRABLE;

ALTER TABLE georitm.tariff_version ADD CONSTRAINT tariff_tariff_version_fk
FOREIGN KEY (tariff_id)
REFERENCES georitm.tariff (id)
ON DELETE CASCADE
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.client_tariff ADD CONSTRAINT tariff_client_tariff_fk
FOREIGN KEY (tariff_id)
REFERENCES georitm.tariff (id)
ON DELETE RESTRICT
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.tariff_scale ADD CONSTRAINT tariff_version_tariff_scale_fk
FOREIGN KEY (tariff_version_id)
REFERENCES georitm.tariff_version (id)
ON DELETE CASCADE
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.alert_action_template ADD CONSTRAINT alert_act_type_alert_act_templ_fk
FOREIGN KEY (act_type_id)
REFERENCES georitm.alert_action_type (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.alert_action ADD CONSTRAINT alert_act_type_alert_act_fk
FOREIGN KEY (act_type_id)
REFERENCES georitm.alert_action_type (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.alert_template ADD CONSTRAINT alert_template_group_alert_template_fk
FOREIGN KEY (group_id)
REFERENCES georitm.alert_template_group (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.notification_alert_groups ADD CONSTRAINT alert_template_group_notification_alert_groups_fk
FOREIGN KEY (alert_group_id)
REFERENCES georitm.alert_template_group (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.object_alerts ADD CONSTRAINT alert_messages_object_alerts_fk
FOREIGN KEY (alert_message_id)
REFERENCES georitm.alert_messages (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.user_log_details ADD CONSTRAINT user_log_user_log_datails_fk
FOREIGN KEY (user_log_id)
REFERENCES georitm.user_log (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.users ADD CONSTRAINT client_users_fk
FOREIGN KEY (client_id)
REFERENCES georitm.clients (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.users_groups ADD CONSTRAINT client_users_groups_fk
FOREIGN KEY (client_id)
REFERENCES georitm.clients (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.auth_roles ADD CONSTRAINT client_auth_roles_fk
FOREIGN KEY (client_id)
REFERENCES georitm.clients (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.positions ADD CONSTRAINT clients_positions_fk
FOREIGN KEY (client_id)
REFERENCES georitm.clients (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.schedule_template ADD CONSTRAINT clients_schedule_template_fk
FOREIGN KEY (client_id)
REFERENCES georitm.clients (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.poi_groups ADD CONSTRAINT clients_poi_groups_fk
FOREIGN KEY (client_id)
REFERENCES georitm.clients (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.poi_types ADD CONSTRAINT clients_poi_types_fk
FOREIGN KEY (client_id)
REFERENCES georitm.clients (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.alert_template ADD CONSTRAINT clients_alert_template_fk
FOREIGN KEY (client_id)
REFERENCES georitm.clients (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.client_properties ADD CONSTRAINT clients_client_properties_fk
FOREIGN KEY (client_id)
REFERENCES georitm.clients (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.alert_action ADD CONSTRAINT clients_alert_action_fk
FOREIGN KEY (client_id)
REFERENCES georitm.clients (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.client_tariff ADD CONSTRAINT clients_client_tariff_fk
FOREIGN KEY (client_id)
REFERENCES georitm.clients (id)
ON DELETE CASCADE
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.accounts ADD CONSTRAINT clients_accounts_fk
FOREIGN KEY (client_id)
REFERENCES georitm.clients (id)
ON DELETE CASCADE
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.expense ADD CONSTRAINT accounts_expense_fk
FOREIGN KEY (account_uuid)
REFERENCES georitm.accounts (uuid)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.income ADD CONSTRAINT accounts_income_fk
FOREIGN KEY (account_uuid)
REFERENCES georitm.accounts (uuid)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.invoice ADD CONSTRAINT accounts_invoice_fk
FOREIGN KEY (account_uuid)
REFERENCES georitm.accounts (uuid)
ON DELETE CASCADE
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.expense_details ADD CONSTRAINT expense_expence_details_fk
FOREIGN KEY (ts, account_uuid)
REFERENCES georitm.expense (ts, account_uuid)
ON DELETE CASCADE
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.notification_alerts ADD CONSTRAINT alert_template_notification_alerts_fk
FOREIGN KEY (alert_template_id)
REFERENCES georitm.alert_template (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.poi_type_properties ADD CONSTRAINT poi_types_poi_type_properties_fk
FOREIGN KEY (poi_type_id)
REFERENCES georitm.poi_types (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.poi ADD CONSTRAINT poi_types_poi_fk
FOREIGN KEY (poi_type_id)
REFERENCES georitm.poi_types (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.poi ADD CONSTRAINT poi_groups_poi_fk
FOREIGN KEY (poi_group_id)
REFERENCES georitm.poi_groups (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.poi_groups ADD CONSTRAINT poi_groups_poi_groups_fk
FOREIGN KEY (parent_id)
REFERENCES georitm.poi_groups (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.staff ADD CONSTRAINT positions_staff_fk
FOREIGN KEY (position_id)
REFERENCES georitm.positions (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.geo_addr_source ADD CONSTRAINT addr_source_geo_addr_source_fk
FOREIGN KEY (source_id)
REFERENCES georitm.addr_source (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.geo_addr_source ADD CONSTRAINT geo_address_geo_addr_source_fk
FOREIGN KEY (address_id)
REFERENCES georitm.geo_address (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.poi ADD CONSTRAINT geo_address_poi_fk
FOREIGN KEY (geo_id)
REFERENCES georitm.geo_address (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.guards ADD CONSTRAINT geo_address_guards_fk
FOREIGN KEY (geo_id)
REFERENCES georitm.geo_address (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.guarg_group_members ADD CONSTRAINT guards_guarg_group_members_fk
FOREIGN KEY (guard_id)
REFERENCES georitm.guards (id)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.guard_calls ADD CONSTRAINT guards_guard_calls_fk
FOREIGN KEY (guard_id)
REFERENCES georitm.guards (id)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.object_guards ADD CONSTRAINT guards_object_guards_fk
FOREIGN KEY (guard_id)
REFERENCES georitm.guards (id)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.poi_properties ADD CONSTRAINT poi_poi_properties_fk
FOREIGN KEY (poi_id)
REFERENCES georitm.poi (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.auth_roles_actions ADD CONSTRAINT auth_roles_auth_roles_actions_fk
FOREIGN KEY (auth_role_id)
REFERENCES georitm.auth_roles (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.auth_roles_subord ADD CONSTRAINT auth_roles_auth_roles_subord_fk1
FOREIGN KEY (junior_role_id)
REFERENCES georitm.auth_roles (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.auth_roles_subord ADD CONSTRAINT auth_roles_auth_roles_subord_fk
FOREIGN KEY (senior_role_id)
REFERENCES georitm.auth_roles (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.users_roles ADD CONSTRAINT auth_roles_users_roles_fk
FOREIGN KEY (auth_role_id)
REFERENCES georitm.auth_roles (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.auth_map ADD CONSTRAINT authable_auth_map_fk
FOREIGN KEY (inventory_id)
REFERENCES georitm.inventory (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.zones ADD CONSTRAINT authable_zones_fk
FOREIGN KEY (id)
REFERENCES georitm.inventory (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.zones_groups_wa ADD CONSTRAINT authable_zones_groups_fk
FOREIGN KEY (id)
REFERENCES georitm.inventory (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.objects ADD CONSTRAINT inventory_object_fk
FOREIGN KEY (id)
REFERENCES georitm.inventory (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.object_groups ADD CONSTRAINT inventory_object_group_fk
FOREIGN KEY (id)
REFERENCES georitm.inventory (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.guard_groups ADD CONSTRAINT inventory_guard_groups_fk
FOREIGN KEY (id)
REFERENCES georitm.inventory (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.guard_groups ADD CONSTRAINT guard_groups_guard_groups_fk
FOREIGN KEY (parent_id)
REFERENCES georitm.guard_groups (id)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.guarg_group_members ADD CONSTRAINT guard_groups_guarg_group_members_fk
FOREIGN KEY (group_id)
REFERENCES georitm.guard_groups (id)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.zones ADD CONSTRAINT zones_groups_zones_fk
FOREIGN KEY (zone_group_id)
REFERENCES georitm.zones_groups_wa (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.zones_groups_wa ADD CONSTRAINT zones_groups_zones_groups_fk
FOREIGN KEY (parent_zones_group_id)
REFERENCES georitm.zones_groups_wa (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.object_groups_zone_groups ADD CONSTRAINT zones_groups_wa_object_groups_zone_groups_fk
FOREIGN KEY (zone_group_id)
REFERENCES georitm.zones_groups_wa (id)
ON DELETE CASCADE
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.zone_rects ADD CONSTRAINT zones_zone_rects_fk
FOREIGN KEY (zone_id)
REFERENCES georitm.zones (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.zone_control ADD CONSTRAINT zones_zone_control_fk
FOREIGN KEY (zone_id)
REFERENCES georitm.zones (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.auth_roles_actions ADD CONSTRAINT auth_actions_auth_roles_actions_fk
FOREIGN KEY (auth_action_id)
REFERENCES georitm.auth_actions (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.auth_users_actions ADD CONSTRAINT auth_actions_auth_users_actions_fk
FOREIGN KEY (auth_action_id)
REFERENCES georitm.auth_actions (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.users ADD CONSTRAINT users_users_fk
FOREIGN KEY (owner_id)
REFERENCES georitm.users (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.users_users_groups_map ADD CONSTRAINT users_users_users_groups_map_fk
FOREIGN KEY (user_id)
REFERENCES georitm.users (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.users_roles ADD CONSTRAINT users_users_roles_fk
FOREIGN KEY (user_id)
REFERENCES georitm.users (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.auth_map ADD CONSTRAINT users_auth_map_fk
FOREIGN KEY (user_id)
REFERENCES georitm.users (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.auth_users_actions ADD CONSTRAINT users_auth_users_actions_fk
FOREIGN KEY (user_id)
REFERENCES georitm.users (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.users_groups ADD CONSTRAINT users_users_groups_fk
FOREIGN KEY (owner_id)
REFERENCES georitm.users (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.staff ADD CONSTRAINT users_staff_fk
FOREIGN KEY (user_id)
REFERENCES georitm.users (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.scheduled_reports ADD CONSTRAINT users_scheduled_reports_fk
FOREIGN KEY (user_id)
REFERENCES georitm.users (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.alerts_log ADD CONSTRAINT users_alerts_log_fk
FOREIGN KEY (user_id)
REFERENCES georitm.users (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.notifications ADD CONSTRAINT users_notifications_fk
FOREIGN KEY (user_id)
REFERENCES georitm.users (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.object_alert_log ADD CONSTRAINT users_object_alert_state_fk
FOREIGN KEY (user_id)
REFERENCES georitm.users (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.guard_calls ADD CONSTRAINT users_guard_calls_fk
FOREIGN KEY (user_id)
REFERENCES georitm.users (id)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.user_subscriptions ADD CONSTRAINT users_user_subscriptions_fk
FOREIGN KEY (user_id)
REFERENCES georitm.users (id)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.user_tokens ADD CONSTRAINT users_user_tokens_fk
FOREIGN KEY (user_id)
REFERENCES georitm.users (id)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.user_properties ADD CONSTRAINT users_user_properties_fk
FOREIGN KEY (user_id)
REFERENCES georitm.users (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.notification_objects ADD CONSTRAINT notifications_notification_objects_fk
FOREIGN KEY (notification_id)
REFERENCES georitm.notifications (id)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.notification_groups ADD CONSTRAINT notifications_notification_groups_fk
FOREIGN KEY (notification_id)
REFERENCES georitm.notifications (id)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.notification_alert_groups ADD CONSTRAINT notifications_notification_alert_groups_fk
FOREIGN KEY (notification_id)
REFERENCES georitm.notifications (id)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.notification_alerts ADD CONSTRAINT notifications_notification_alerts_fk
FOREIGN KEY (notification_id)
REFERENCES georitm.notifications (id)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.notification_addresses ADD CONSTRAINT notifications_notification_addresses_fk
FOREIGN KEY (notification_id)
REFERENCES georitm.notifications (id)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.schedule ADD CONSTRAINT staff_schedule_fk
FOREIGN KEY (staff_id)
REFERENCES georitm.staff (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.users_groups ADD CONSTRAINT users_groups_users_groups_fk
FOREIGN KEY (parent_users_group_id)
REFERENCES georitm.users_groups (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.users_users_groups_map ADD CONSTRAINT users_groups_users_users_groups_map_fk
FOREIGN KEY (users_group_id)
REFERENCES georitm.users_groups (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.object_type_parameters ADD CONSTRAINT parameter_type_object_type_parameters_fk
FOREIGN KEY (parameter_type_id)
REFERENCES georitm.parameter_types (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.calibrations ADD CONSTRAINT parameter_type_calibrations_fk
FOREIGN KEY (parameter_id)
REFERENCES georitm.parameter_types (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.object_groups ADD CONSTRAINT object_group_object_group_fk
FOREIGN KEY (parent_id)
REFERENCES georitm.object_groups (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.object_group_members ADD CONSTRAINT object_group_object_group_members_fk
FOREIGN KEY (group_id)
REFERENCES georitm.object_groups (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.object_group_history ADD CONSTRAINT object_groups_object_group_history_fk
FOREIGN KEY (from_group_id)
REFERENCES georitm.object_groups (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.object_group_history ADD CONSTRAINT object_groups_object_group_history_fk1
FOREIGN KEY (to_group_id)
REFERENCES georitm.object_groups (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.notification_groups ADD CONSTRAINT object_groups_notification_groups_fk
FOREIGN KEY (object_group_id)
REFERENCES georitm.object_groups (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.object_groups_zone_groups ADD CONSTRAINT object_groups_object_groups_zone_groups_fk
FOREIGN KEY (object_group_id)
REFERENCES georitm.object_groups (id)
ON DELETE CASCADE
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.objects ADD CONSTRAINT object_type_object_fk
FOREIGN KEY (type_id)
REFERENCES georitm.object_types (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.object_type_parameters ADD CONSTRAINT object_type_object_type_parameters_fk
FOREIGN KEY (object_type_id)
REFERENCES georitm.object_types (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.object_group_members ADD CONSTRAINT object_object_group_members_fk
FOREIGN KEY (object_id)
REFERENCES georitm.objects (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.object_settings ADD CONSTRAINT object_settings_fk
FOREIGN KEY (object_id)
REFERENCES georitm.objects (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.calibrations ADD CONSTRAINT object_calibrations_fk
FOREIGN KEY (object_id)
REFERENCES georitm.objects (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.object_group_history ADD CONSTRAINT objects_object_group_history_fk
FOREIGN KEY (object_id)
REFERENCES georitm.objects (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.schedule ADD CONSTRAINT objects_schedule_fk
FOREIGN KEY (object_id)
REFERENCES georitm.objects (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.clear_route_tasks ADD CONSTRAINT objects_clear_route_tasks_fk
FOREIGN KEY (object_id)
REFERENCES georitm.objects (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.object_alerts ADD CONSTRAINT objects_object_alerts_fk
FOREIGN KEY (object_id)
REFERENCES georitm.objects (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.object_areas ADD CONSTRAINT objects_object_areas_fk
FOREIGN KEY (object_id)
REFERENCES georitm.objects (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.pictures ADD CONSTRAINT objects_pictures_fk
FOREIGN KEY (object_id)
REFERENCES georitm.objects (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.notification_objects ADD CONSTRAINT objects_notification_objects_fk
FOREIGN KEY (object_id)
REFERENCES georitm.objects (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.zone_control ADD CONSTRAINT objects_zone_control_fk
FOREIGN KEY (object_id)
REFERENCES georitm.objects (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.object_alert_log ADD CONSTRAINT objects_object_alert_state_fk
FOREIGN KEY (object_id)
REFERENCES georitm.objects (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.guard_calls ADD CONSTRAINT objects_guard_calls_fk
FOREIGN KEY (object_id)
REFERENCES georitm.objects (id)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.object_guards ADD CONSTRAINT objects_object_guards_fk
FOREIGN KEY (object_id)
REFERENCES georitm.objects (id)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.object_status_history ADD CONSTRAINT objects_object_status_history_fk
FOREIGN KEY (object_id)
REFERENCES georitm.objects (id)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.object_status ADD CONSTRAINT objects_object_status_fk
FOREIGN KEY (object_id)
REFERENCES georitm.objects (id)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.expense_details ADD CONSTRAINT objects_expence_details_fk
FOREIGN KEY (object_id)
REFERENCES georitm.objects (id)
ON DELETE RESTRICT
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.notification_areas ADD CONSTRAINT notification_objects_notification_areas_fk
FOREIGN KEY (notification_object_id)
REFERENCES georitm.notification_objects (id)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.notification_zones ADD CONSTRAINT notification_areas_notification_zones_fk
FOREIGN KEY (notificaton_area_id)
REFERENCES georitm.notification_areas (id)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.area_zones ADD CONSTRAINT object_areas_area_zones_fk
FOREIGN KEY (area_id)
REFERENCES georitm.object_areas (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.object_area_roles ADD CONSTRAINT object_areas_object_area_roles_fk
FOREIGN KEY (area_id)
REFERENCES georitm.object_areas (id)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.area_zone_faults ADD CONSTRAINT area_zones_area_zone_faults_fk
FOREIGN KEY (area_zone_id)
REFERENCES georitm.area_zones (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.alerts_log ADD CONSTRAINT object_alerts_alerts_log_fk
FOREIGN KEY (alert_id)
REFERENCES georitm.object_alerts (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE georitm.alert_channel_info ADD CONSTRAINT object_alerts_alert_channel_info_fk
FOREIGN KEY (alert_id)
REFERENCES georitm.object_alerts (id)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;
