SET default_tablespace = georitm;

CREATE TABLE georitm_data.public_transport_marks (
  object_id INTEGER NOT NULL,
  ts TIMESTAMP NOT NULL,
  osm_node_id BIGINT NOT NULL,
  dist DOUBLE PRECISION NOT NULL,
  description VARCHAR(255),
  lat INTEGER,
  lon INTEGER,
  geo_id INTEGER,
  CONSTRAINT georitm_data_transport_marks_pk PRIMARY KEY (object_id, ts, osm_node_id)
);
COMMENT ON TABLE georitm_data.public_transport_marks IS 'Отметки о движении общественного транспорта';
COMMENT ON COLUMN georitm_data.public_transport_marks.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm_data.public_transport_marks.ts IS 'Время приближения к отметке';
COMMENT ON COLUMN georitm_data.public_transport_marks.osm_node_id IS 'OSM Id метки';
COMMENT ON COLUMN georitm_data.public_transport_marks.dist IS 'Расстояние';
COMMENT ON COLUMN georitm_data.public_transport_marks.description IS 'Описание';
COMMENT ON COLUMN georitm_data.public_transport_marks.lat IS 'Широта';
COMMENT ON COLUMN georitm_data.public_transport_marks.lon IS 'Долгота';
COMMENT ON COLUMN georitm_data.public_transport_marks.geo_id IS 'Идентификатор гео-метки';


CREATE TABLE georitm_data.accelerations (
  object_id INTEGER NOT NULL,
  start_ts TIMESTAMP NOT NULL,
  end_ts TIMESTAMP NOT NULL,
  dur INTEGER NOT NULL,
  dist INTEGER,
  accel DOUBLE PRECISION NOT NULL,
  lat INTEGER,
  lon INTEGER,
  geo_id INTEGER,
  CONSTRAINT accelerations_pk PRIMARY KEY (object_id, start_ts)
);
COMMENT ON TABLE georitm_data.accelerations IS 'Ускорения/торможения';
COMMENT ON COLUMN georitm_data.accelerations.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm_data.accelerations.start_ts IS 'Начало ускорения/торможения';
COMMENT ON COLUMN georitm_data.accelerations.end_ts IS 'Конец ускорения/торможения';
COMMENT ON COLUMN georitm_data.accelerations.dur IS 'Продолжительность';
COMMENT ON COLUMN georitm_data.accelerations.dist IS 'Дистанция';
COMMENT ON COLUMN georitm_data.accelerations.accel IS 'Ускорение/торможение';
COMMENT ON COLUMN georitm_data.accelerations.lat IS 'Широта';
COMMENT ON COLUMN georitm_data.accelerations.lon IS 'Долгота';
COMMENT ON COLUMN georitm_data.accelerations.geo_id IS 'Идентификатор гео-метки';


CREATE TABLE georitm_data.speedings (
  object_id INTEGER NOT NULL,
  start_ts TIMESTAMP NOT NULL,
  end_ts TIMESTAMP NOT NULL,
  dur INTEGER NOT NULL,
  dist INTEGER,
  max_speed INTEGER,
  speed_limit INTEGER,
  lat INTEGER,
  lon INTEGER,
  geo_id INTEGER,
  CONSTRAINT speedings_pk PRIMARY KEY (object_id, start_ts)
);
COMMENT ON TABLE georitm_data.speedings IS 'Превышения скорости';
COMMENT ON COLUMN georitm_data.speedings.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm_data.speedings.start_ts IS 'Начало превышения';
COMMENT ON COLUMN georitm_data.speedings.end_ts IS 'Конец превышения';
COMMENT ON COLUMN georitm_data.speedings.dur IS 'Продолжительность';
COMMENT ON COLUMN georitm_data.speedings.dist IS 'Дистанция';
COMMENT ON COLUMN georitm_data.speedings.max_speed IS 'Максимальная скорость';
COMMENT ON COLUMN georitm_data.speedings.speed_limit IS 'Ограничение скорости';
COMMENT ON COLUMN georitm_data.speedings.lat IS 'Широта';
COMMENT ON COLUMN georitm_data.speedings.lon IS 'Долгота';
COMMENT ON COLUMN georitm_data.speedings.geo_id IS 'Идентификатор гео-метки';


CREATE TABLE georitm_data.trajectory_stat (
  object_id INTEGER NOT NULL,
  matched_points BIGINT NOT NULL,
  unmatched_points BIGINT NOT NULL,
  avg_an DOUBLE PRECISION NOT NULL,
  avg_al DOUBLE PRECISION NOT NULL,
  avg_pdop DOUBLE PRECISION NOT NULL,
  avg_deviation DOUBLE PRECISION NOT NULL,
  CONSTRAINT trajectory_stat_pk PRIMARY KEY (object_id)
);
COMMENT ON TABLE georitm_data.trajectory_stat IS 'Статистика качества траекторий';
COMMENT ON COLUMN georitm_data.trajectory_stat.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm_data.trajectory_stat.matched_points IS 'Привязанные точки';
COMMENT ON COLUMN georitm_data.trajectory_stat.unmatched_points IS 'Не привязанные точки';
COMMENT ON COLUMN georitm_data.trajectory_stat.avg_an IS 'Средняя точность привязки (количество)';
COMMENT ON COLUMN georitm_data.trajectory_stat.avg_al IS 'Средняя точнось привязки (пробег)';
COMMENT ON COLUMN georitm_data.trajectory_stat.avg_pdop IS 'Средняя потеря точности';
COMMENT ON COLUMN georitm_data.trajectory_stat.avg_deviation IS 'Среднее отклонение от траектории';


CREATE TABLE georitm_data.object_state_timestamps (
  object_id INTEGER NOT NULL,
  point_ts TIMESTAMP,
  event_ts TIMESTAMP,
  parameter_ts TIMESTAMP,
  route_history_ts TIMESTAMP,
  CONSTRAINT object_state_timestamps_pk PRIMARY KEY (object_id)
);
COMMENT ON TABLE georitm_data.object_state_timestamps IS 'Временная таблица для хранения параметров импорта';
COMMENT ON COLUMN georitm_data.object_state_timestamps.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm_data.object_state_timestamps.point_ts IS 'Штамп времени последнего обновления точек';
COMMENT ON COLUMN georitm_data.object_state_timestamps.event_ts IS 'Штамп времени последнего обновления событий';
COMMENT ON COLUMN georitm_data.object_state_timestamps.parameter_ts IS 'Штамп времени последнего обновления параметров';
COMMENT ON COLUMN georitm_data.object_state_timestamps.route_history_ts IS 'Штамп времени последнего обновления истории маршрута';


CREATE SEQUENCE georitm_data.loss_of_signal_id_seq;

CREATE TABLE georitm_data.loss_of_signal (
  id INTEGER NOT NULL DEFAULT nextval('georitm_data.loss_of_signal_id_seq'::regclass),
  object_id INTEGER NOT NULL,
  date_from TIMESTAMP NOT NULL,
  date_to TIMESTAMP NOT NULL,
  lstype SMALLINT NOT NULL,
  lat INTEGER NOT NULL,
  lon INTEGER NOT NULL,
  alt INTEGER NOT NULL,
  geo_id INTEGER,
  CONSTRAINT loss_of_signal_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm_data.loss_of_signal IS 'Потери сигняла';
COMMENT ON COLUMN georitm_data.loss_of_signal.id IS 'Идентификатор потери сигнала';
COMMENT ON COLUMN georitm_data.loss_of_signal.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm_data.loss_of_signal.date_from IS 'Дата От';
COMMENT ON COLUMN georitm_data.loss_of_signal.date_to IS 'Дата До';
COMMENT ON COLUMN georitm_data.loss_of_signal.lstype IS 'Тип потери сигнала (потеря фиксации/отключение прибора)';
COMMENT ON COLUMN georitm_data.loss_of_signal.lat IS 'Широта';
COMMENT ON COLUMN georitm_data.loss_of_signal.lon IS 'Долгота';
COMMENT ON COLUMN georitm_data.loss_of_signal.alt IS 'Высота';
COMMENT ON COLUMN georitm_data.loss_of_signal.geo_id IS 'Метка положения';


ALTER SEQUENCE georitm_data.loss_of_signal_id_seq OWNED BY georitm_data.loss_of_signal.id;

CREATE INDEX loss_of_signal_objdatefrom_idx
  ON georitm_data.loss_of_signal
  ( date_from );

CREATE INDEX loss_of_signal_objdateto_idx
  ON georitm_data.loss_of_signal
  ( date_to );

CREATE SEQUENCE georitm_data.parkmove_id_seq;

CREATE TABLE georitm_data.parkmove (
  id INTEGER NOT NULL DEFAULT nextval('georitm_data.parkmove_id_seq'::regclass),
  date_from TIMESTAMP NOT NULL,
  date_to TIMESTAMP NOT NULL,
  dist INTEGER NOT NULL,
  max_speed DOUBLE PRECISION NOT NULL,
  lat INTEGER NOT NULL,
  lon INTEGER NOT NULL,
  alt INTEGER NOT NULL,
  object_id INTEGER NOT NULL,
  pmtype SMALLINT NOT NULL,
  geo_id INTEGER,
  CONSTRAINT parkmove_pk PRIMARY KEY (id)
);
COMMENT ON TABLE georitm_data.parkmove IS 'Период непрерывного движения';
COMMENT ON COLUMN georitm_data.parkmove.id IS 'Идентификатор стоянки или движения';
COMMENT ON COLUMN georitm_data.parkmove.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm_data.parkmove.date_from IS 'Дата От';
COMMENT ON COLUMN georitm_data.parkmove.date_to IS 'Дата До';
COMMENT ON COLUMN georitm_data.parkmove.dist IS 'Дистанция';
COMMENT ON COLUMN georitm_data.parkmove.max_speed IS 'Максимальная скорость';
COMMENT ON COLUMN georitm_data.parkmove.lat IS 'Широта';
COMMENT ON COLUMN georitm_data.parkmove.lon IS 'Долгота';
COMMENT ON COLUMN georitm_data.parkmove.alt IS 'Высота';
COMMENT ON COLUMN georitm_data.parkmove.pmtype IS 'Тип стоянки или движения';
COMMENT ON COLUMN georitm_data.parkmove.geo_id IS 'Метка положения';


ALTER SEQUENCE georitm_data.parkmove_id_seq OWNED BY georitm_data.parkmove.id;

CREATE INDEX parkmove_datefrom_idx
  ON georitm_data.parkmove
  ( date_from );

CREATE INDEX parkmove_dateto_idx
  ON georitm_data.parkmove
  ( date_to );

CREATE TABLE georitm_data.object_parameters (
  object_id INTEGER NOT NULL,
  parameter_type_id INTEGER NOT NULL,
  parameter_ts TIMESTAMP NOT NULL,
  parameter_value DOUBLE PRECISION NOT NULL,
  vcount INTEGER NOT NULL,
  ext_id BIGINT,
  lat INTEGER NOT NULL,
  lon INTEGER NOT NULL,
  alt INTEGER NOT NULL,
  geo_id INTEGER,
  CONSTRAINT object_parameters_pk PRIMARY KEY (parameter_ts, object_id, parameter_type_id)
);
COMMENT ON TABLE georitm_data.object_parameters IS 'Параметр объекта';
COMMENT ON COLUMN georitm_data.object_parameters.parameter_ts IS 'Время фиксации параметра';
COMMENT ON COLUMN georitm_data.object_parameters.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm_data.object_parameters.parameter_type_id IS 'Идентификатор типа параметра';
COMMENT ON COLUMN georitm_data.object_parameters.parameter_value IS 'Значение параметра';
COMMENT ON COLUMN georitm_data.object_parameters.vcount IS 'Счетчик повтора значения';
COMMENT ON COLUMN georitm_data.object_parameters.ext_id IS 'Идентификатор во внешней системе. Используется для первичного импорта, потом может быть удален.';
COMMENT ON COLUMN georitm_data.object_parameters.lat IS 'Широта';
COMMENT ON COLUMN georitm_data.object_parameters.lon IS 'Долгота';
COMMENT ON COLUMN georitm_data.object_parameters.alt IS 'Высота';
COMMENT ON COLUMN georitm_data.object_parameters.geo_id IS 'Метка положения';


CREATE INDEX object_parameters_parameter_ts_idx
  ON georitm_data.object_parameters
  ( parameter_ts ASC );

CREATE TABLE georitm_data.object_events (
  event_ts TIMESTAMP NOT NULL,
  object_id INTEGER NOT NULL,
  state BIGINT NOT NULL,
  ext_id BIGINT,
  lat INTEGER NOT NULL,
  lon INTEGER NOT NULL,
  geo_id INTEGER,
  alt INTEGER NOT NULL,
  CONSTRAINT object_events_pk PRIMARY KEY (event_ts, object_id)
);
COMMENT ON TABLE georitm_data.object_events IS 'Событие';
COMMENT ON COLUMN georitm_data.object_events.event_ts IS 'Время наступления события';
COMMENT ON COLUMN georitm_data.object_events.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm_data.object_events.state IS 'Маска значений по событиям';
COMMENT ON COLUMN georitm_data.object_events.ext_id IS 'Идентификатор во внешней системе. Используется для первичного импорта, потом может быть удален.';
COMMENT ON COLUMN georitm_data.object_events.lat IS 'Широта';
COMMENT ON COLUMN georitm_data.object_events.lon IS 'Долгота';
COMMENT ON COLUMN georitm_data.object_events.geo_id IS 'Метка положения';
COMMENT ON COLUMN georitm_data.object_events.alt IS 'Высота';


CREATE INDEX object_events_event_ts_idx
  ON georitm_data.object_events
  ( event_ts );

CREATE TABLE georitm_data.points (
  object_id INTEGER NOT NULL,
  point_ts TIMESTAMP NOT NULL,
  lat INTEGER NOT NULL,
  lon INTEGER NOT NULL,
  alt INTEGER NOT NULL,
  spd INTEGER NOT NULL,
  rid INTEGER NOT NULL,
  record_type INTEGER NOT NULL,
  calculated_speed INTEGER,
  ext_id BIGINT,
  parkmove_id INTEGER,
  geo_id INTEGER,
  CONSTRAINT points_pk PRIMARY KEY (object_id, point_ts)
);
COMMENT ON TABLE georitm_data.points IS 'Пространственная точка';
COMMENT ON COLUMN georitm_data.points.point_ts IS 'Время записи точки';
COMMENT ON COLUMN georitm_data.points.object_id IS 'Идентификатор объекта';
COMMENT ON COLUMN georitm_data.points.lat IS 'Широта';
COMMENT ON COLUMN georitm_data.points.lon IS 'Длогота';
COMMENT ON COLUMN georitm_data.points.alt IS 'Высота';
COMMENT ON COLUMN georitm_data.points.spd IS 'Скорость, метров в час';
COMMENT ON COLUMN georitm_data.points.rid IS 'Номер ячейки памяти прибора. Для совместимости';
COMMENT ON COLUMN georitm_data.points.record_type IS 'Тип записи';
COMMENT ON COLUMN georitm_data.points.calculated_speed IS 'Расчетная скорость';
COMMENT ON COLUMN georitm_data.points.ext_id IS 'Идентификатор во внешней системе. Используется для первичного импорта, потом может быть удален.';
COMMENT ON COLUMN georitm_data.points.parkmove_id IS 'Идентификатор стоянки или движения';
COMMENT ON COLUMN georitm_data.points.geo_id IS 'Метка положения';


CREATE INDEX points_ts_idx
  ON georitm_data.points
  ( point_ts ASC );

CREATE INDEX points_calc_speed_idx
  ON georitm_data.points USING BTREE
  ( calculated_speed ASC );

ALTER TABLE georitm_data.points ADD CONSTRAINT parkmove_points_fk
FOREIGN KEY (parkmove_id)
REFERENCES georitm_data.parkmove (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;