SET default_tablespace = georitm;

CREATE TABLE idp.last_packets (
                from_id INTEGER NOT NULL,
                to_id INTEGER NOT NULL,
                packet_id BIGINT NOT NULL,
                CONSTRAINT last_packets_pk PRIMARY KEY (from_id, to_id)
);
COMMENT ON TABLE idp.last_packets IS 'Последний отправленный пакет';
COMMENT ON COLUMN idp.last_packets.from_id IS 'Коннектор-отправитель';
COMMENT ON COLUMN idp.last_packets.to_id IS 'Коннектор-получатель';
COMMENT ON COLUMN idp.last_packets.packet_id IS 'Идентификатор пакета';


CREATE TABLE idp.firmware_objects (
                imei BIGINT NOT NULL,
                updating BOOLEAN DEFAULT FALSE NOT NULL,
                last_block INTEGER DEFAULT 0 NOT NULL,
                block_count INTEGER DEFAULT 0 NOT NULL,
                old_firmware VARCHAR(50),
                new_firmware VARCHAR(50),
                begin_date TIMESTAMP,
                end_date TIMESTAMP,
                digest VARCHAR(50),
                CONSTRAINT firmware_objects_pk PRIMARY KEY (imei)
);
COMMENT ON TABLE idp.firmware_objects IS 'версия и статус обновления прошивки';
COMMENT ON COLUMN idp.firmware_objects.imei IS 'IMEI';
COMMENT ON COLUMN idp.firmware_objects.updating IS 'индикатор текущего обновления';
COMMENT ON COLUMN idp.firmware_objects.last_block IS 'номер последнего записанного в прибор блока прошивки';
COMMENT ON COLUMN idp.firmware_objects.block_count IS 'количество блоков, входящих в new_firmware';
COMMENT ON COLUMN idp.firmware_objects.old_firmware IS 'версия предыдущей прошивки';
COMMENT ON COLUMN idp.firmware_objects.new_firmware IS 'текущая версия прошивки или версия будующей прошивки (если updating = TRUE)';
COMMENT ON COLUMN idp.firmware_objects.begin_date IS 'дата начала перепрошивки';
COMMENT ON COLUMN idp.firmware_objects.end_date IS 'дата завершения перепрошивки';
COMMENT ON COLUMN idp.firmware_objects.digest IS 'Строковое представление дайджеста (MD5) прошивки';


CREATE TABLE idp.route_table (
                from_id INTEGER NOT NULL,
                to_id INTEGER NOT NULL,
                recovery_policy_id INTEGER NOT NULL,
                CONSTRAINT route_table_pk PRIMARY KEY (from_id, to_id)
);
COMMENT ON TABLE idp.route_table IS 'Таблица маршрутизации';
COMMENT ON COLUMN idp.route_table.from_id IS 'Источник';
COMMENT ON COLUMN idp.route_table.to_id IS 'Приемник';
COMMENT ON COLUMN idp.route_table.recovery_policy_id IS 'Идентификатор политики';


CREATE SEQUENCE idp.connectors_id_seq;

CREATE TABLE idp.connectors (
                id INTEGER NOT NULL DEFAULT nextval('idp.connectors_id_seq'),
                name VARCHAR(255) NOT NULL,
                type_id INTEGER NOT NULL,
                protocol_id INTEGER NOT NULL,
                is_outbound BOOLEAN DEFAULT false NOT NULL,
                connected_at TIMESTAMP,
                disconnected_at TIMESTAMP,
                group_id INTEGER NOT NULL,
                is_deleted BOOLEAN DEFAULT false NOT NULL,
                is_started BOOLEAN DEFAULT false NOT NULL,
                CONSTRAINT connectors_pk PRIMARY KEY (id)
);
COMMENT ON TABLE idp.connectors IS 'Коннекторы';
COMMENT ON COLUMN idp.connectors.id IS 'Идентификатор коннектора';
COMMENT ON COLUMN idp.connectors.name IS 'Имя коннектора';
COMMENT ON COLUMN idp.connectors.is_outbound IS 'Исходящий';
COMMENT ON COLUMN idp.connectors.connected_at IS 'Время соединения';
COMMENT ON COLUMN idp.connectors.disconnected_at IS 'Время разъединения';
COMMENT ON COLUMN idp.connectors.group_id IS 'Идентификатор группы';
COMMENT ON COLUMN idp.connectors.is_started IS 'Запущен';


ALTER SEQUENCE idp.connectors_id_seq OWNED BY idp.connectors.id;

CREATE SEQUENCE idp.protocols_id_seq;

CREATE TABLE idp.protocols (
                id INTEGER NOT NULL DEFAULT nextval('idp.protocols_id_seq'),
                name VARCHAR(255) NOT NULL,
                code VARCHAR(20) NOT NULL,
                CONSTRAINT protocols_pk PRIMARY KEY (id)
);
COMMENT ON TABLE idp.protocols IS 'Справочник протоколов';
COMMENT ON COLUMN idp.protocols.id IS 'Идентификатор протокола';
COMMENT ON COLUMN idp.protocols.name IS 'Имя протокола';
COMMENT ON COLUMN idp.protocols.code IS 'Мнемонический код протокола';


ALTER SEQUENCE idp.protocols_id_seq OWNED BY idp.protocols.id;

CREATE TABLE idp.translations (
                from_id INTEGER NOT NULL,
                to_id INTEGER NOT NULL,
                translate_from VARCHAR(10) NOT NULL,
                translate_to VARCHAR(10),
                CONSTRAINT translations_pk PRIMARY KEY (from_id, to_id, translate_from)
);
COMMENT ON TABLE idp.translations IS 'Подмена событий';
COMMENT ON COLUMN idp.translations.from_id IS 'Источник';
COMMENT ON COLUMN idp.translations.to_id IS 'Приемник';
COMMENT ON COLUMN idp.translations.translate_from IS 'Какое событие заменять';
COMMENT ON COLUMN idp.translations.translate_to IS 'На какое событие заменять. NULL -- отбрасывать.';


CREATE TABLE idp.object_properties (
                object_imei BIGINT NOT NULL,
                property_key VARCHAR(50) NOT NULL,
                property_value VARCHAR(255) NOT NULL,
                CONSTRAINT object_properties_pk PRIMARY KEY (object_imei, property_key)
);
COMMENT ON TABLE idp.object_properties IS 'Свойства объекта';
COMMENT ON COLUMN idp.object_properties.object_imei IS 'IMEI';
COMMENT ON COLUMN idp.object_properties.property_key IS 'Ключ свойства';
COMMENT ON COLUMN idp.object_properties.property_value IS 'Значение';


CREATE TABLE idp.sessions (
                uuid CHAR(36) NOT NULL,
                connected_at TIMESTAMP,
                disconnected_at TIMESTAMP,
                connector_id INTEGER NOT NULL,
                imei BIGINT NOT NULL,
                CONSTRAINT sessions_pk PRIMARY KEY (uuid)
);
COMMENT ON TABLE idp.sessions IS 'Подключения';
COMMENT ON COLUMN idp.sessions.uuid IS 'Идентификатор сессии';
COMMENT ON COLUMN idp.sessions.connected_at IS 'Время соединения';
COMMENT ON COLUMN idp.sessions.disconnected_at IS 'Время окончания';
COMMENT ON COLUMN idp.sessions.imei IS 'IMEI';


CREATE SEQUENCE idp.deffered_commands_id_seq;

CREATE TABLE idp.deffered_commands (
                id INTEGER NOT NULL DEFAULT nextval('idp.deffered_commands_id_seq'),
                imei BIGINT NOT NULL,
                command_idx INTEGER NOT NULL,
                dc_function INTEGER NOT NULL,
                arguments VARCHAR(2048),
                CONSTRAINT deffered_commands_pk PRIMARY KEY (id)
);
COMMENT ON TABLE idp.deffered_commands IS 'Отложенные комманды';
COMMENT ON COLUMN idp.deffered_commands.id IS 'Первичный ключ';
COMMENT ON COLUMN idp.deffered_commands.imei IS 'IMEI';
COMMENT ON COLUMN idp.deffered_commands.command_idx IS 'Индекс команды';
COMMENT ON COLUMN idp.deffered_commands.dc_function IS 'Функция';
COMMENT ON COLUMN idp.deffered_commands.arguments IS 'Аргументв команды';


ALTER SEQUENCE idp.deffered_commands_id_seq OWNED BY idp.deffered_commands.id;

CREATE SEQUENCE idp.packet_dumps_id_seq;

CREATE TABLE idp.packet_dumps (
                id BIGINT NOT NULL DEFAULT nextval('idp.packet_dumps_id_seq'::regclass),
                dump_ts TIMESTAMP NOT NULL,
                payload BYTEA NOT NULL,
                session_uuid CHAR(36) NOT NULL,
                CONSTRAINT packet_dumps_pk PRIMARY KEY (id)
);
COMMENT ON TABLE idp.packet_dumps IS 'Дамп пакетов';
COMMENT ON COLUMN idp.packet_dumps.id IS 'Идентивикатор';
COMMENT ON COLUMN idp.packet_dumps.dump_ts IS 'Время';
COMMENT ON COLUMN idp.packet_dumps.payload IS 'Содержимое';
COMMENT ON COLUMN idp.packet_dumps.session_uuid IS 'Идентификатор сессии';


ALTER SEQUENCE idp.packet_dumps_id_seq OWNED BY idp.packet_dumps.id;

CREATE TABLE idp.objects (
                imei BIGINT NOT NULL,
                name VARCHAR(255),
                firmware VARCHAR(50),
                password VARCHAR(20),
                ext_id INTEGER,
                last_connected TIMESTAMP,
                last_disconnected TIMESTAMP,
                connector_id INTEGER,
                CONSTRAINT objects_pk PRIMARY KEY (imei)
);
COMMENT ON TABLE idp.objects IS 'Объекты';
COMMENT ON COLUMN idp.objects.imei IS 'IMEI';
COMMENT ON COLUMN idp.objects.name IS 'Имя объекта';
COMMENT ON COLUMN idp.objects.firmware IS 'Версия прошивки';
COMMENT ON COLUMN idp.objects.password IS 'Пароль на подключение';
COMMENT ON COLUMN idp.objects.ext_id IS 'Внешний идентификатор';
COMMENT ON COLUMN idp.objects.last_connected IS 'Время последнего выхода на связь';
COMMENT ON COLUMN idp.objects.last_disconnected IS 'Время последнего ухода со связи';
COMMENT ON COLUMN idp.objects.connector_id IS 'Коннектор последнего выхода на сязь';


CREATE TABLE idp.session_cache (
                connected_at TIMESTAMP,
                imei BIGINT NOT NULL
);


CREATE TABLE idp.instance_id (
                id CHAR(36) NOT NULL,
                mac VARCHAR(255) NOT NULL,
                CONSTRAINT instance_id_pk PRIMARY KEY (id)
);
COMMENT ON TABLE idp.instance_id IS 'Идентификатор сервиса';
COMMENT ON COLUMN idp.instance_id.id IS 'Идентификатор';
COMMENT ON COLUMN idp.instance_id.mac IS 'MAC-адрес';


CREATE SEQUENCE idp.users_id_seq;

CREATE TABLE idp.users (
                id INTEGER NOT NULL DEFAULT nextval('idp.users_id_seq'),
                login VARCHAR(255) NOT NULL,
                password VARCHAR(50) NOT NULL,
                parent_id INTEGER,
                CONSTRAINT users_pk PRIMARY KEY (id)
);
COMMENT ON TABLE idp.users IS 'Пользователи';
COMMENT ON COLUMN idp.users.id IS 'Идентификатор пользователя';
COMMENT ON COLUMN idp.users.login IS 'Логин';
COMMENT ON COLUMN idp.users.password IS 'Пароль';
COMMENT ON COLUMN idp.users.parent_id IS 'Идентификатор родительского пользователя';


ALTER SEQUENCE idp.users_id_seq OWNED BY idp.users.id;

CREATE SEQUENCE idp.connector_types_id_seq;

CREATE TABLE idp.connector_types (
                id INTEGER NOT NULL DEFAULT nextval('idp.connector_types_id_seq'::regclass),
                name VARCHAR(255) NOT NULL,
                code VARCHAR(20) NOT NULL,
                CONSTRAINT connector_types_pk PRIMARY KEY (id)
);
COMMENT ON TABLE idp.connector_types IS 'Тип коннестора';
COMMENT ON COLUMN idp.connector_types.id IS 'Идентификатор типа коннектора';
COMMENT ON COLUMN idp.connector_types.name IS 'Имя типа коннектора';
COMMENT ON COLUMN idp.connector_types.code IS 'Мнемонический код типа коннектора';


ALTER SEQUENCE idp.connector_types_id_seq OWNED BY idp.connector_types.id;

CREATE TABLE idp.dump_info (
                id BIGINT NOT NULL,
                imei BIGINT NOT NULL,
                device_ts TIMESTAMP NOT NULL,
                dump_type SMALLINT NOT NULL,
                CONSTRAINT dump_info_pk PRIMARY KEY (id)
);
COMMENT ON TABLE idp.dump_info IS 'Информация о пакете';
COMMENT ON COLUMN idp.dump_info.id IS 'Идентивикатор';
COMMENT ON COLUMN idp.dump_info.imei IS 'IMEI прибора';
COMMENT ON COLUMN idp.dump_info.device_ts IS 'Время в приборе';
COMMENT ON COLUMN idp.dump_info.dump_type IS 'Тип пакета. 0 -- CID, 1 -- history...';


CREATE TABLE idp.group_users (
                user_id INTEGER NOT NULL,
                group_id INTEGER NOT NULL,
                CONSTRAINT group_users_pk PRIMARY KEY (user_id, group_id)
);
COMMENT ON TABLE idp.group_users IS 'Принадлежность группы пользователю';
COMMENT ON COLUMN idp.group_users.user_id IS 'Идентификатор пользователя';
COMMENT ON COLUMN idp.group_users.group_id IS 'Идентификатор группы';


CREATE TABLE idp.white_list (
                imei BIGINT NOT NULL,
                connector_id INTEGER NOT NULL,
                white SMALLINT DEFAULT 1 NOT NULL,
                CONSTRAINT white_list_pk PRIMARY KEY (imei, connector_id)
);


CREATE TABLE idp.type_properties (
                type_id INTEGER NOT NULL,
                property_key VARCHAR(50) NOT NULL,
                description VARCHAR(255) NOT NULL,
                view_order INTEGER,
                property_type VARCHAR(15) NOT NULL,
                property_default VARCHAR(255) NOT NULL,
                CONSTRAINT type_properties_pk PRIMARY KEY (type_id, property_key)
);
COMMENT ON TABLE idp.type_properties IS 'Свойства коннектора определенного типа';
COMMENT ON COLUMN idp.type_properties.type_id IS 'Идентификатор типа коннектора';
COMMENT ON COLUMN idp.type_properties.property_key IS 'Ключ свойства';
COMMENT ON COLUMN idp.type_properties.description IS 'Описание свойства';
COMMENT ON COLUMN idp.type_properties.view_order IS 'Порядок отображения в форме';
COMMENT ON COLUMN idp.type_properties.property_type IS 'Тип свойства';
COMMENT ON COLUMN idp.type_properties.property_default IS 'Значение по умолчанию';


CREATE TABLE idp.protocol_properties (
                protocol_id INTEGER NOT NULL,
                property_key VARCHAR(50) NOT NULL,
                description VARCHAR(255) NOT NULL,
                view_order INTEGER,
                property_type VARCHAR(15) NOT NULL,
                property_default VARCHAR(255) NOT NULL,
                CONSTRAINT protocol_properties_pk PRIMARY KEY (protocol_id, property_key)
);
COMMENT ON TABLE idp.protocol_properties IS 'Свойства протокола';
COMMENT ON COLUMN idp.protocol_properties.protocol_id IS 'Идентификатор протокола';
COMMENT ON COLUMN idp.protocol_properties.property_key IS 'Ключ свойства';
COMMENT ON COLUMN idp.protocol_properties.description IS 'Описание свойства';
COMMENT ON COLUMN idp.protocol_properties.view_order IS 'Порядок отображения в форме';
COMMENT ON COLUMN idp.protocol_properties.property_type IS 'Тип свойства';
COMMENT ON COLUMN idp.protocol_properties.property_default IS 'Значение по умолчанию';


CREATE TABLE idp.connector_properties (
                connector_id INTEGER NOT NULL,
                property_key VARCHAR(50) NOT NULL,
                property_value VARCHAR(255) NOT NULL,
                CONSTRAINT connector_properties_pk PRIMARY KEY (connector_id, property_key)
);
COMMENT ON TABLE idp.connector_properties IS 'Свойства коннектора';
COMMENT ON COLUMN idp.connector_properties.connector_id IS 'Идентификатор коннектора';
COMMENT ON COLUMN idp.connector_properties.property_key IS 'Ключ свойства';
COMMENT ON COLUMN idp.connector_properties.property_value IS 'Значение свойства коннектора';


CREATE TABLE idp.route_properties (
                from_id INTEGER NOT NULL,
                to_id INTEGER NOT NULL,
                property_key VARCHAR(50) NOT NULL,
                property_value VARCHAR(255) NOT NULL,
                CONSTRAINT route_properties_pk PRIMARY KEY (from_id, to_id, property_key)
);
COMMENT ON TABLE idp.route_properties IS 'Свойства марщрутизации';
COMMENT ON COLUMN idp.route_properties.from_id IS 'Источник';
COMMENT ON COLUMN idp.route_properties.to_id IS 'Приемник';
COMMENT ON COLUMN idp.route_properties.property_key IS 'Ключ свойситва';
COMMENT ON COLUMN idp.route_properties.property_value IS 'Значение свойства';


CREATE SEQUENCE idp.recovery_policies_id_seq;

CREATE TABLE idp.recovery_policies (
                id INTEGER NOT NULL DEFAULT nextval('idp.recovery_policies_id_seq'::regclass),
                name VARCHAR(255) NOT NULL,
                code VARCHAR(32) NOT NULL,
                CONSTRAINT recovery_policies_pk PRIMARY KEY (id)
);
COMMENT ON TABLE idp.recovery_policies IS 'Политики восстановления';
COMMENT ON COLUMN idp.recovery_policies.id IS 'Идентификатор политики';
COMMENT ON COLUMN idp.recovery_policies.name IS 'Имя политики';
COMMENT ON COLUMN idp.recovery_policies.code IS 'Мнемонический код политики';


ALTER SEQUENCE idp.recovery_policies_id_seq OWNED BY idp.recovery_policies.id;

CREATE SEQUENCE idp.connector_groups_id_seq;

CREATE TABLE idp.connector_groups (
                id INTEGER NOT NULL DEFAULT nextval('idp.connector_groups_id_seq'::regclass),
                name VARCHAR(50) NOT NULL,
                parent_id INTEGER,
                CONSTRAINT connector_groups_pk PRIMARY KEY (id)
);
COMMENT ON TABLE idp.connector_groups IS 'Группа коннектора';
COMMENT ON COLUMN idp.connector_groups.id IS 'Идентификатор группы';
COMMENT ON COLUMN idp.connector_groups.name IS 'Имя группы';
COMMENT ON COLUMN idp.connector_groups.parent_id IS 'Родительская группа';


ALTER SEQUENCE idp.connector_groups_id_seq OWNED BY idp.connector_groups.id;

ALTER TABLE idp.translations ADD CONSTRAINT route_table_translations_fk
FOREIGN KEY (from_id, to_id)
REFERENCES idp.route_table (from_id, to_id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE idp.route_properties ADD CONSTRAINT route_table_route_properties_fk
FOREIGN KEY (from_id, to_id)
REFERENCES idp.route_table (from_id, to_id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE idp.route_table ADD CONSTRAINT connectors_route_table_fk
FOREIGN KEY (from_id)
REFERENCES idp.connectors (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE idp.route_table ADD CONSTRAINT connectors_route_table_fk1
FOREIGN KEY (to_id)
REFERENCES idp.connectors (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE idp.sessions ADD CONSTRAINT connectors_sessions_fk
FOREIGN KEY (connector_id)
REFERENCES idp.connectors (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE idp.white_list ADD CONSTRAINT connectors_white_list_fk
FOREIGN KEY (connector_id)
REFERENCES idp.connectors (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE idp.connector_properties ADD CONSTRAINT connectors_connector_properties_fk
FOREIGN KEY (connector_id)
REFERENCES idp.connectors (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE idp.connectors ADD CONSTRAINT protocols_connectors_fk
FOREIGN KEY (protocol_id)
REFERENCES idp.protocols (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE idp.protocol_properties ADD CONSTRAINT protocols_protocol_properties_fk
FOREIGN KEY (protocol_id)
REFERENCES idp.protocols (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE idp.packet_dumps ADD CONSTRAINT sessions_packet_dumps_fk
FOREIGN KEY (session_uuid)
REFERENCES idp.sessions (uuid)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE idp.dump_info ADD CONSTRAINT packet_dumps_dump_info_fk
FOREIGN KEY (id)
REFERENCES idp.packet_dumps (id)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE idp.firmware_objects ADD CONSTRAINT objects_firmware_objects_fk
FOREIGN KEY (imei)
REFERENCES idp.objects (imei)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE idp.object_properties ADD CONSTRAINT objects_object_properties_fk
FOREIGN KEY (object_imei)
REFERENCES idp.objects (imei)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE idp.sessions ADD CONSTRAINT objects_sessions_fk
FOREIGN KEY (imei)
REFERENCES idp.objects (imei)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE idp.deffered_commands ADD CONSTRAINT objects_deffered_commands_fk
FOREIGN KEY (imei)
REFERENCES idp.objects (imei)
ON DELETE CASCADE
ON UPDATE CASCADE
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE idp.users ADD CONSTRAINT users_users_fk
FOREIGN KEY (parent_id)
REFERENCES idp.users (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE idp.group_users ADD CONSTRAINT users_group_users_fk
FOREIGN KEY (user_id)
REFERENCES idp.users (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE idp.connectors ADD CONSTRAINT connector_type_connectors_fk
FOREIGN KEY (type_id)
REFERENCES idp.connector_types (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE idp.type_properties ADD CONSTRAINT connector_type_type_properties_fk
FOREIGN KEY (type_id)
REFERENCES idp.connector_types (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE idp.route_table ADD CONSTRAINT recovery_policies_route_table_fk
FOREIGN KEY (recovery_policy_id)
REFERENCES idp.recovery_policies (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE idp.connectors ADD CONSTRAINT connetor_groups_connectors_fk
FOREIGN KEY (group_id)
REFERENCES idp.connector_groups (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE idp.group_users ADD CONSTRAINT connetor_groups_group_users_fk
FOREIGN KEY (group_id)
REFERENCES idp.connector_groups (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;

ALTER TABLE idp.connector_groups ADD CONSTRAINT connetor_groups_connetor_groups_fk
FOREIGN KEY (parent_id)
REFERENCES idp.connector_groups (id)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;