SET default_tablespace = georitm;

CREATE SEQUENCE voyager.sgn_id_seq;

CREATE TABLE voyager.sgn (
                ID INTEGER NOT NULL DEFAULT nextval('voyager.sgn_id_seq'::regclass),
                COMN VARCHAR(50),
                ID_MES INTEGER,
                ID_OBJ INTEGER,
                ID_POD INTEGER,
                ID_PPL INTEGER,
                ID_PR INTEGER,
                ID_ZON INTEGER,
                LINEN INTEGER,
                PHONE VARCHAR(50),
                PRIM VARCHAR(500),
                RAZDEL INTEGER,
                REAL_DATE TIMESTAMP,
                RECEIVERN INTEGER,
                RID INTEGER,
                SDATE TIMESTAMP,
                STR1 VARCHAR(500),
                STR2 VARCHAR(500),
                XUSER VARCHAR(50),
                ZONA INTEGER,
                ID_SGN INTEGER DEFAULT 0 NOT NULL,
                CONSTRAINT sgn_pk PRIMARY KEY (ID)
);


ALTER SEQUENCE voyager.sgn_id_seq OWNED BY voyager.sgn.ID;

CREATE INDEX id_mes
 ON voyager.sgn USING BTREE
 ( ID_MES ASC );

CREATE INDEX id_ppl
 ON voyager.sgn USING BTREE
 ( ID_PPL ASC );

CREATE INDEX id_pr
 ON voyager.sgn USING BTREE
 ( ID_PR ASC );

CREATE INDEX id_zon
 ON voyager.sgn USING BTREE
 ( ID_ZON ASC );

CREATE INDEX sgn_idx1
 ON voyager.sgn USING BTREE
 ( ID_OBJ ASC );

CREATE INDEX sgn_idx2
 ON voyager.sgn USING BTREE
 ( SDATE ASC );

CREATE SEQUENCE voyager.can_records_id_seq;

CREATE TABLE voyager.can_records (
                ID BIGINT NOT NULL DEFAULT nextval('voyager.can_records_id_seq'::regclass),
                ID_OBJ INTEGER DEFAULT 1 NOT NULL,
                REC_DATE TIMESTAMP NOT NULL,
                RID SMALLINT,
                REC_TYPE SMALLINT,
                LAT DOUBLE PRECISION,
                LON DOUBLE PRECISION,
                SPD DOUBLE PRECISION,
                POWER SMALLINT,
                D1 SMALLINT,
                D2 SMALLINT,
                D3 SMALLINT,
                D4 SMALLINT,
                D5 SMALLINT,
                D6 SMALLINT,
                VEHICLE_P SMALLINT,
                FUEL_LEVEL SMALLINT,
                FUEL_RATE SMALLINT,
                E_SPEED SMALLINT,
                E_HOURS INTEGER,
                VEHICLE_D INTEGER,
                AXLE_W SMALLINT,
                E_TEMP SMALLINT,
                ID_PRM1 INTEGER,
                VALUE_PRM1 INTEGER,
                ID_PRM2 INTEGER,
                VALUE_PRM2 INTEGER,
                ID_PRM3 INTEGER,
                VALUE_PRM3 INTEGER,
                ID_PRM4 INTEGER,
                VALUE_PRM4 INTEGER,
                ID_PRM5 INTEGER,
                VALUE_PRM5 BIGINT,
                ID_PRM6 INTEGER,
                VALUE_PRM6 BIGINT,
                AXLE_NUMBER SMALLINT DEFAULT 0,
                FUEL_LITRES INTEGER DEFAULT 0,
                FUEL_SUMM INTEGER DEFAULT 0,
                PERIMETR SMALLINT DEFAULT 0,
                TRANSMISSION SMALLINT DEFAULT 0,
                ENGINE_REGIMS SMALLINT DEFAULT 0,
                SERVICE_DISTANCE INTEGER,
                CONSTRAINT can_records_pk PRIMARY KEY (ID)
);


ALTER SEQUENCE voyager.can_records_id_seq OWNED BY voyager.can_records.ID;

CREATE INDEX id_obj
 ON voyager.can_records USING BTREE
 ( ID_OBJ ASC, REC_DATE ASC );

CREATE INDEX date_obj_can
 ON voyager.can_records USING BTREE
 ( ID_OBJ ASC, REC_DATE ASC );

CREATE SEQUENCE voyager.obj_id_seq;

CREATE TABLE voyager.obj (
                ID INTEGER NOT NULL DEFAULT nextval('voyager.obj_id_seq'::regclass),
                CONTROL_GROUP INTEGER,
                COURSE DOUBLE PRECISION,
                CAN_COEFF DOUBLE PRECISION DEFAULT 1 NOT NULL,
                D1 TIMESTAMP,
                D2 TIMESTAMP,
                D3 TIMESTAMP,
                D4 TIMESTAMP,
                D5 TIMESTAMP,
                D6 TIMESTAMP,
                D_ONLINE TIMESTAMP,
                FCONSUMH_SUMMER1 DOUBLE PRECISION,
                FCONSUMH_SUMMER2 DOUBLE PRECISION,
                FCONSUMH_WINTER1 DOUBLE PRECISION,
                FCONSUMH_WINTER2 DOUBLE PRECISION,
                FCONSUM_SUMMER1 DOUBLE PRECISION,
                FCONSUM_SUMMER2 DOUBLE PRECISION,
                FCONSUM_WINTER1 DOUBLE PRECISION,
                FCONSUM_WINTER2 DOUBLE PRECISION,
                FIX_GPS INTEGER,
                G1 INTEGER,
                G2 INTEGER,
                G3 INTEGER,
                G4 INTEGER,
                G5 INTEGER,
                GPRS_TTW INTEGER,
                I1 INTEGER,
                I10 INTEGER,
                I11 INTEGER,
                I12 INTEGER,
                I13 INTEGER,
                I14 INTEGER,
                I15 INTEGER,
                I16 INTEGER,
                I17 INTEGER,
                I18 INTEGER,
                I2 INTEGER,
                I3 INTEGER,
                I4 INTEGER,
                I5 INTEGER,
                I6 INTEGER,
                I7 INTEGER,
                I8 INTEGER,
                I9 INTEGER,
                ID_AVT INTEGER,
                ID_CNT INTEGER,
                ID_GPS INTEGER,
                ID_HISTORY INTEGER,
                ID_OBJGR INTEGER,
                ID_OBS INTEGER,
                ID_PIC INTEGER,
                ID_SLD INTEGER,
                ID_SMS1 INTEGER,
                ID_SMS2 INTEGER,
                ID_SMS3 INTEGER,
                ID_V1 INTEGER,
                ID_V2 INTEGER,
                ID_VISIBLE INTEGER,
                INETPASSWORD VARCHAR(50),
                LAT DOUBLE PRECISION,
                LOCAL_RID INTEGER,
                LON DOUBLE PRECISION,
                OBJ VARCHAR(256),
                OPR_COUNT INTEGER,
                PERIOD INTEGER,
                PIC1 VARCHAR(256),
                PIC2 VARCHAR(256),
                PIC3 VARCHAR(256),
                PIC4 VARCHAR(256),
                PIC5 VARCHAR(256),
                PIC6 VARCHAR(256),
                PIC7 VARCHAR(256),
                PIC8 VARCHAR(256),
                POINT_DATE TIMESTAMP,
                R1 INTEGER,
                R2 INTEGER,
                REMOTE_RID INTEGER,
                S1 VARCHAR(500),
                S10 VARCHAR(500),
                S11 VARCHAR(500),
                S12 VARCHAR(500),
                S13 VARCHAR(500),
                S14 VARCHAR(500),
                S15 VARCHAR(500),
                S16 VARCHAR(500),
                S17 VARCHAR(500),
                S18 VARCHAR(500),
                S19 VARCHAR(500),
                S2 VARCHAR(500),
                S20 VARCHAR(500),
                S21 VARCHAR(500),
                S22 VARCHAR(500),
                S23 VARCHAR(500),
                S24 VARCHAR(500),
                S25 VARCHAR(500),
                S26 VARCHAR(500),
                S27 VARCHAR(500),
                S28 VARCHAR(500),
                S29 VARCHAR(500),
                S3 VARCHAR(500),
                S30 VARCHAR(500),
                S4 VARCHAR(500),
                S5 VARCHAR(500),
                S6 VARCHAR(500),
                S7 VARCHAR(500),
                S8 VARCHAR(500),
                S9 VARCHAR(500),
                SH5 INTEGER,
                SH6 INTEGER,
                SPD DOUBLE PRECISION,
                AN_TYPE1 INTEGER,
                AN_TYPE2 INTEGER,
                I19 INTEGER,
                I20 INTEGER,
                PHONE1 VARCHAR(50),
                PHONE2 VARCHAR(50),
                PHONE3 VARCHAR(50),
                MAIL1 VARCHAR(50),
                MAIL_ON INTEGER,
                ID_STEAL INTEGER,
                ID_TARIFF INTEGER DEFAULT 0 NOT NULL,
                LAST_PAY_DATE TIMESTAMP,
                USER_LOCKED SMALLINT DEFAULT 0 NOT NULL,
                SYS_LOCKED SMALLINT DEFAULT 0 NOT NULL,
                USER_LOCKED_DATE TIMESTAMP,
                SYS_LOCKED_DATE TIMESTAMP,
                S31 VARCHAR(256),
                S32 VARCHAR(256),
                S33 VARCHAR(256),
                S34 VARCHAR(256),
                S35 VARCHAR(256),
                S36 VARCHAR(256),
                S37 VARCHAR(256),
                S38 VARCHAR(256),
                S39 VARCHAR(256),
                S40 VARCHAR(256),
                S41 VARCHAR(256),
                state INTEGER DEFAULT 0 NOT NULL,
                razdel INTEGER DEFAULT 0 NOT NULL,
                change_date TIMESTAMP,
                change_by VARCHAR(100),
                create_date TIMESTAMP,
                error_220v SMALLINT DEFAULT 0 NOT NULL,
                atest_state INTEGER DEFAULT 0 NOT NULL,
                FUEL_SENSOR_TYPE SMALLINT DEFAULT 0 NOT NULL,
                imei VARCHAR(32),
                CONSTRAINT obj_pk PRIMARY KEY (ID)
);


ALTER SEQUENCE voyager.obj_id_seq OWNED BY voyager.obj.ID;

CREATE INDEX id_avt
 ON voyager.obj USING BTREE
 ( ID_AVT ASC );

CREATE INDEX id_cnt
 ON voyager.obj USING BTREE
 ( ID_CNT ASC );

CREATE INDEX id_gps
 ON voyager.obj USING BTREE
 ( ID_GPS ASC );

CREATE INDEX id_history
 ON voyager.obj USING BTREE
 ( ID_HISTORY ASC );

CREATE INDEX id_objgr
 ON voyager.obj USING BTREE
 ( ID_OBJGR ASC );

CREATE INDEX id_obs
 ON voyager.obj USING BTREE
 ( ID_OBS ASC );

CREATE INDEX id_sld
 ON voyager.obj USING BTREE
 ( ID_SLD ASC );

CREATE INDEX id_sms1
 ON voyager.obj USING BTREE
 ( ID_SMS1 ASC );

CREATE INDEX id_sms2
 ON voyager.obj USING BTREE
 ( ID_SMS2 ASC );

CREATE INDEX id_sms3
 ON voyager.obj USING BTREE
 ( ID_SMS3 ASC );

CREATE INDEX id_visible
 ON voyager.obj USING BTREE
 ( ID_VISIBLE ASC );

CREATE SEQUENCE voyager.records_id_seq;

CREATE TABLE voyager.records (
                ID BIGINT NOT NULL DEFAULT nextval('voyager.records_id_seq'::regclass),
                ID_OBJ INTEGER,
                REC_DATE TIMESTAMP,
                RID SMALLINT,
                REC_TYPE SMALLINT,
                LAT DOUBLE PRECISION,
                LON DOUBLE PRECISION,
                SPD DOUBLE PRECISION,
                POWER SMALLINT,
                D1 SMALLINT,
                D2 SMALLINT,
                D3 SMALLINT,
                D4 SMALLINT,
                D5 SMALLINT,
                D6 SMALLINT,
                AN1 SMALLINT,
                AN2 SMALLINT,
                CAR_POWER SMALLINT,
                CONSTRAINT records_pk PRIMARY KEY (ID)
);


ALTER SEQUENCE voyager.records_id_seq OWNED BY voyager.records.ID;

CREATE INDEX date_obj
 ON voyager.records USING BTREE
 ( ID_OBJ ASC, REC_DATE ASC );

CREATE INDEX rec_date
 ON voyager.records USING BTREE
 ( REC_DATE ASC );

CREATE TABLE voyager.record_parameters (
                record_id BIGINT NOT NULL,
                parameter_id INTEGER NOT NULL,
                val DOUBLE PRECISION NOT NULL,
                CONSTRAINT record_parameters_pk PRIMARY KEY (record_id, parameter_id)
);
COMMENT ON TABLE voyager.record_parameters IS 'Дополнительные парамметры записи';
COMMENT ON COLUMN voyager.record_parameters.record_id IS 'Идентификатор записи';
COMMENT ON COLUMN voyager.record_parameters.parameter_id IS 'ID параметра';


ALTER TABLE voyager.record_parameters ADD CONSTRAINT records_record_parameters_fk
FOREIGN KEY (record_id)
REFERENCES voyager.records (ID)
ON DELETE NO ACTION
ON UPDATE NO ACTION
DEFERRABLE INITIALLY DEFERRED;;

CREATE SEQUENCE voyager.object_info_id_seq;

CREATE TABLE voyager.object_info (
                id INTEGER NOT NULL DEFAULT nextval('voyager.object_info_id_seq'::regclass),
                object_id INTEGER,
                version VARCHAR(64),
                mode_id INTEGER,
                revision_id INTEGER,
                modem_id INTEGER,
                flash_id INTEGER,
                cpu_id INTEGER,
                meta_data VARCHAR(32) DEFAULT '0',
                CONSTRAINT object_info_pk PRIMARY KEY (id)
);
